"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.startApp = startApp;
var _execa = _interopRequireDefault(require("execa"));
var _getModularRoot = _interopRequireDefault(require("../utils/getModularRoot"));
var logger = _interopRequireWildcard(require("../utils/logger"));
function _getRequireWildcardCache(nodeInterop) { if (typeof WeakMap !== "function") return null; var cacheBabelInterop = new WeakMap(); var cacheNodeInterop = new WeakMap(); return (_getRequireWildcardCache = function (nodeInterop) { return nodeInterop ? cacheNodeInterop : cacheBabelInterop; })(nodeInterop); }
function _interopRequireWildcard(obj, nodeInterop) { if (!nodeInterop && obj && obj.__esModule) { return obj; } if (obj === null || typeof obj !== "object" && typeof obj !== "function") { return { default: obj }; } var cache = _getRequireWildcardCache(nodeInterop); if (cache && cache.has(obj)) { return cache.get(obj); } var newObj = {}; var hasPropertyDescriptor = Object.defineProperty && Object.getOwnPropertyDescriptor; for (var key in obj) { if (key !== "default" && Object.prototype.hasOwnProperty.call(obj, key)) { var desc = hasPropertyDescriptor ? Object.getOwnPropertyDescriptor(obj, key) : null; if (desc && (desc.get || desc.set)) { Object.defineProperty(newObj, key, desc); } else { newObj[key] = obj[key]; } } } newObj.default = obj; if (cache) { cache.set(obj, newObj); } return newObj; }
function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }
function modular(cwd, str, opts = {}) {
  return (0, _execa.default)('yarnpkg', ['modular', ...str.split(' ')], {
    cwd: cwd,
    cleanup: true,
    ...opts
  });
}
const START_APP_TIMEOUT = 60 * 1000;
async function startApp(appPath, opts = {}, modularRoot) {
  const cwd = modularRoot ? modularRoot : (0, _getModularRoot.default)();
  const devServer = modular(cwd, `start ${appPath}`, {
    cleanup: true,
    ...opts
  });
  await new Promise((resolve, reject) => {
    if (!devServer.stdout) {
      return reject(new Error('The dev server could not produce any output on /dev/stdout.'));
    }
    if (!devServer.stderr) {
      return reject(new Error('The dev server could not produce any output on /dev/stderr.'));
    }

    // If the Promise has completed we need to bail out of any further handlers that
    // are executed, because otherwise we can end up trying to log after tests are done.
    // We use a 'completed' variable to do this -- in an ideal world we'd cleanup
    // the listeners.
    //
    // See: https://github.com/jpmorganchase/modular/pull/107#discussion_r493791918
    let completed = false;
    const startAppTimeout = setTimeout(() => {
      if (completed) return;
      completed = true;
      reject(new Error(`The app at ${appPath} never started within the configured ${START_APP_TIMEOUT}ms timeout period.`));
    }, START_APP_TIMEOUT);
    devServer.stdout.on('data', data => {
      if (completed) return;
      const output = data.toString();
      if (/Something is already running on port (\d+)./.test(output)) {
        clearTimeout(startAppTimeout);
        completed = true;
        return reject(new Error(output));
      }
      if (/Compiled successfully!/.test(output)) {
        clearTimeout(startAppTimeout);
        completed = true;
        return resolve(true);
      }
    });
    devServer.stderr.on('data', data => {
      if (completed) return;
      const output = data.toString();
      logger.error(output);
      clearTimeout(startAppTimeout);
      completed = true;
      return reject(new Error(output));
    });

    // eslint-disable-next-line @typescript-eslint/no-floating-promises
    devServer.on('error', err => {
      if (completed) return;
      logger.error(String(err));
      logger.error(err.stack || '');
      clearTimeout(startAppTimeout);
      completed = true;
      reject(err);
    });
  });

  // We can't return the raw execa child process,
  // because we need to `await` until the dev server
  // starts above, but don't want to wait until the
  // process itself finishes.
  return {
    kill: () => {
      devServer.kill('SIGKILL');
      return devServer;
    }
  };
}
//# sourceMappingURL=start-app.js.map