"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.getRepositoryField = getRepositoryField;
var path = _interopRequireWildcard(require("path"));
var fs = _interopRequireWildcard(require("fs-extra"));
var _execAsync = _interopRequireDefault(require("../../utils/execAsync"));
var _getModularRoot = _interopRequireDefault(require("../../utils/getModularRoot"));
function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }
function _getRequireWildcardCache(nodeInterop) { if (typeof WeakMap !== "function") return null; var cacheBabelInterop = new WeakMap(); var cacheNodeInterop = new WeakMap(); return (_getRequireWildcardCache = function (nodeInterop) { return nodeInterop ? cacheNodeInterop : cacheBabelInterop; })(nodeInterop); }
function _interopRequireWildcard(obj, nodeInterop) { if (!nodeInterop && obj && obj.__esModule) { return obj; } if (obj === null || typeof obj !== "object" && typeof obj !== "function") { return { default: obj }; } var cache = _getRequireWildcardCache(nodeInterop); if (cache && cache.has(obj)) { return cache.get(obj); } var newObj = {}; var hasPropertyDescriptor = Object.defineProperty && Object.getOwnPropertyDescriptor; for (var key in obj) { if (key !== "default" && Object.prototype.hasOwnProperty.call(obj, key)) { var desc = hasPropertyDescriptor ? Object.getOwnPropertyDescriptor(obj, key) : null; if (desc && (desc.get || desc.set)) { Object.defineProperty(newObj, key, desc); } else { newObj[key] = obj[key]; } } } newObj.default = obj; if (cache) { cache.set(obj, newObj); } return newObj; }
async function getRelativePathInRepo(packagePath) {
  const {
    stdout: gitRepoPath
  } = await (0, _execAsync.default)('git', ['rev-parse', '--show-toplevel'], {
    stdout: 'pipe'
  });
  return path.relative(gitRepoPath, packagePath).split(path.win32.sep).join(path.posix.sep);
}
async function getRepositoryField(packagePath) {
  const modularRoot = (0, _getModularRoot.default)();
  const pathInRepo = await getRelativePathInRepo(packagePath);
  const rootPackageJsonPath = path.join(modularRoot, 'package.json');
  const rootPackageJson = await fs.readJSON(rootPackageJsonPath);
  if (rootPackageJson.repository && pathInRepo) {
    return {
      type: 'git',
      url: rootPackageJson.repository,
      directory: pathInRepo
    };
  }
  return undefined;
}
//# sourceMappingURL=getRepositoryField.js.map