"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.buildPackage = buildPackage;
var path = _interopRequireWildcard(require("path"));
var _changeCase = require("change-case");
var _fsExtra = _interopRequireDefault(require("fs-extra"));
var _npmPacklist = _interopRequireDefault(require("npm-packlist"));
var _micromatch = _interopRequireDefault(require("micromatch"));
var _getPrefixedLogger = _interopRequireDefault(require("../../utils/getPrefixedLogger"));
var _getModularRoot = _interopRequireDefault(require("../../utils/getModularRoot"));
var _makeBundle = require("./makeBundle");
var _makeTypings = require("./makeTypings");
var _getRelativeLocation = _interopRequireDefault(require("../../utils/getRelativeLocation"));
var _getRepositoryField = require("./getRepositoryField");
var _maybeCopyRootLicense = require("./maybeCopyRootLicense");
function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }
function _getRequireWildcardCache(nodeInterop) { if (typeof WeakMap !== "function") return null; var cacheBabelInterop = new WeakMap(); var cacheNodeInterop = new WeakMap(); return (_getRequireWildcardCache = function (nodeInterop) { return nodeInterop ? cacheNodeInterop : cacheBabelInterop; })(nodeInterop); }
function _interopRequireWildcard(obj, nodeInterop) { if (!nodeInterop && obj && obj.__esModule) { return obj; } if (obj === null || typeof obj !== "object" && typeof obj !== "function") { return { default: obj }; } var cache = _getRequireWildcardCache(nodeInterop); if (cache && cache.has(obj)) { return cache.get(obj); } var newObj = {}; var hasPropertyDescriptor = Object.defineProperty && Object.getOwnPropertyDescriptor; for (var key in obj) { if (key !== "default" && Object.prototype.hasOwnProperty.call(obj, key)) { var desc = hasPropertyDescriptor ? Object.getOwnPropertyDescriptor(obj, key) : null; if (desc && (desc.get || desc.set)) { Object.defineProperty(newObj, key, desc); } else { newObj[key] = obj[key]; } } } newObj.default = obj; if (cache) { cache.set(obj, newObj); } return newObj; }
// While working on this file, be aware that builds
// could be happening simultaneously across packages, so
// try be 'thread-safe'. No state outside of functions

const outputDirectory = 'dist';
const IGNORED_FILES = ['!package.json', '!src', '!dist-cjs', '!dist-es', '!dist-types'];
async function buildPackage(target, preserveModules = true, includePrivate = false) {
  const modularRoot = (0, _getModularRoot.default)();
  const packagePath = await (0, _getRelativeLocation.default)(target);
  const logger = (0, _getPrefixedLogger.default)(target);
  const targetOutputDirectory = path.join(modularRoot, outputDirectory, (0, _changeCase.paramCase)(target));

  // ensure the root build folder is ready
  await _fsExtra.default.mkdirp(targetOutputDirectory);
  await _fsExtra.default.emptyDir(targetOutputDirectory);

  // Generate the typings for a package first so that we can do type checking and don't waste time bundling otherwise
  await (0, _makeTypings.makeTypings)(target);

  // generate the js files now that we know we have a valid package
  const publicPackageJson = await (0, _makeBundle.makeBundle)(target, preserveModules, includePrivate);
  if (!publicPackageJson.repository) {
    publicPackageJson.repository = await (0, _getRepositoryField.getRepositoryField)(packagePath);
  }
  await _fsExtra.default.writeJson(path.join(targetOutputDirectory, 'package.json'), publicPackageJson, {
    spaces: 2
  });

  // cool. now we copy across any files which we need using npm-packlist
  const packlist = await (0, _npmPacklist.default)({
    path: path.join(modularRoot, packagePath)
  });
  (0, _micromatch.default)(packlist, (publicPackageJson.files || []).concat(IGNORED_FILES)).forEach(fileName => {
    logger.log(`Copying ${fileName}`);
    return _fsExtra.default.copyFileSync(path.join(modularRoot, packagePath, fileName), path.join(targetOutputDirectory, fileName));
  });
  (0, _maybeCopyRootLicense.maybeCopyRootLicense)(target, targetOutputDirectory);

  /// and... that's it
  logger.log(`built ${target} in ${targetOutputDirectory}`);
}
//# sourceMappingURL=index.js.map