"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = createEsbuildConfig;
var path = _interopRequireWildcard(require("path"));
var _isCi = _interopRequireDefault(require("is-ci"));
var _builtinModules = _interopRequireDefault(require("builtin-modules"));
var _getClientEnvironment = _interopRequireDefault(require("../../common-scripts/getClientEnvironment"));
var logger = _interopRequireWildcard(require("../../../utils/logger"));
var _moduleScopePlugin = _interopRequireDefault(require("../plugins/moduleScopePlugin"));
var _svgr = _interopRequireDefault(require("../plugins/svgr"));
var _workerFactoryPlugin = _interopRequireDefault(require("../plugins/workerFactoryPlugin"));
var _config = require("../../../utils/config");
function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }
function _getRequireWildcardCache(nodeInterop) { if (typeof WeakMap !== "function") return null; var cacheBabelInterop = new WeakMap(); var cacheNodeInterop = new WeakMap(); return (_getRequireWildcardCache = function (nodeInterop) { return nodeInterop ? cacheNodeInterop : cacheBabelInterop; })(nodeInterop); }
function _interopRequireWildcard(obj, nodeInterop) { if (!nodeInterop && obj && obj.__esModule) { return obj; } if (obj === null || typeof obj !== "object" && typeof obj !== "function") { return { default: obj }; } var cache = _getRequireWildcardCache(nodeInterop); if (cache && cache.has(obj)) { return cache.get(obj); } var newObj = {}; var hasPropertyDescriptor = Object.defineProperty && Object.getOwnPropertyDescriptor; for (var key in obj) { if (key !== "default" && Object.prototype.hasOwnProperty.call(obj, key)) { var desc = hasPropertyDescriptor ? Object.getOwnPropertyDescriptor(obj, key) : null; if (desc && (desc.get || desc.set)) { Object.defineProperty(newObj, key, desc); } else { newObj[key] = obj[key]; } } } newObj.default = obj; if (cache) { cache.set(obj, newObj); } return newObj; }
function createEsbuildConfig(paths, config = {}) {
  const {
    plugins: configPlugins,
    ...partialConfig
  } = config;
  const plugins = [(0, _moduleScopePlugin.default)(paths), (0, _svgr.default)(), (0, _workerFactoryPlugin.default)()].concat(configPlugins || []);
  const define = Object.assign({}, (0, _getClientEnvironment.default)(paths.publicUrlOrPath).stringified, {
    global: 'window'
  });
  logger.debug(`Using target: ${partialConfig.target.join(', ')}`);

  // merge and de-duplicate node builtins with external in the parameters
  const external = [...new Set((partialConfig.external ?? []).concat(_builtinModules.default))];
  return {
    entryPoints: [paths.appIndexJs],
    plugins,
    bundle: true,
    resolveExtensions: paths.moduleFileExtensions.map(extension => `.${extension}`),
    sourcemap: (0, _config.getConfig)('generateSourceMap', paths.appPath),
    loader: {
      // loaders for images which are supported as files
      '.avif': 'file',
      '.bmp': 'file',
      '.gif': 'file',
      '.jpg': 'file',
      '.jpeg': 'file',
      '.png': 'file',
      '.webp': 'file',
      // font file format loaders
      '.woff': 'file',
      '.ttf': 'file',
      // enable JSX in js files
      '.js': 'jsx'
    },
    logLevel: 'silent',
    target: partialConfig.target,
    format: 'esm',
    color: !_isCi.default,
    define,
    metafile: true,
    minify: true,
    outbase: paths.modularRoot,
    absWorkingDir: paths.modularRoot,
    outdir: paths.appBuild,
    publicPath: paths.publicUrlOrPath,
    nodePaths: (process.env.NODE_PATH || '').split(path.delimiter),
    ...partialConfig,
    // this was merged previously; do not override.
    external
  };
}
//# sourceMappingURL=createEsbuildConfig.js.map