"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.createRewriteDependenciesPlugin = createRewriteDependenciesPlugin;
var _importInfo = require("../../../utils/importInfo");
function createRewriteDependenciesPlugin(importInfo) {
  const dependencyRewritePlugin = {
    name: 'dependency-rewrite',
    setup(build) {
      // Filter on external dependencies
      build.onResolve({
        filter: /^[a-z0-9-~]|@/,
        namespace: 'file'
      }, args => {
        // Construct the full url from import map
        const path = (0, _importInfo.rewriteModuleSpecifier)(importInfo, args.path);
        if (path) {
          // Rewrite the path taking the submodule into account
          if (path.endsWith('.css')) {
            // This is a global CSS import from the CDN. Mark for rewriting with a placeholder.
            return {
              path,
              namespace: 'rewritable-css-import'
            };
          }
          // Just rewrite and mark as external. It will be ignored the next resolve cycle
          return {
            path,
            external: true
          };
        } else {
          // Dependency has been filtered out: ignore and bundle
          return {};
        }
      });
      build.onLoad({
        filter: /^[a-z0-9-~]|@/,
        namespace: 'rewritable-css-import'
      }, args => {
        // Rewrite to noop placeholder: dependency will be written in output package.json
        // and generated index.html, no need to load it in the page
        return {
          contents: `/* Placeholder for ${args.path} - see package.json */`
        };
      });
    }
  };
  return dependencyRewritePlugin;
}
//# sourceMappingURL=rewriteDependenciesPlugin.js.map