"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = startEsbuild;
var http = _interopRequireWildcard(require("http"));
var https = _interopRequireWildcard(require("https"));
var path = _interopRequireWildcard(require("path"));
var fs = _interopRequireWildcard(require("fs-extra"));
var _expressWs = _interopRequireDefault(require("express-ws"));
var express = _interopRequireWildcard(require("express"));
var _chalk = _interopRequireDefault(require("chalk"));
var esbuild = _interopRequireWildcard(require("esbuild"));
var _mime = require("mime");
var _isCi = _interopRequireDefault(require("is-ci"));
var _memoize = _interopRequireDefault(require("../../../utils/memoize"));
var _getClientEnvironment = _interopRequireDefault(require("../../common-scripts/getClientEnvironment"));
var _incrementalCompile = _interopRequireDefault(require("./plugins/incrementalCompile"));
var _incrementalReporter = _interopRequireDefault(require("./plugins/incrementalReporter"));
var _wsReload = _interopRequireDefault(require("./plugins/wsReload"));
var _metafileReporter = _interopRequireDefault(require("./plugins/metafileReporter"));
var _firstCompile = _interopRequireDefault(require("./plugins/firstCompile"));
var _openBrowser = _interopRequireDefault(require("../../common-scripts/openBrowser"));
var logger = _interopRequireWildcard(require("../../../utils/logger"));
var _urls = _interopRequireDefault(require("../../common-scripts/urls"));
var _api = require("../api");
var _createEsbuildConfig = _interopRequireDefault(require("../config/createEsbuildConfig"));
var _errorOverlayMiddleware = _interopRequireDefault(require("../../common-scripts/errorOverlayMiddleware"));
var _getHost = _interopRequireDefault(require("./utils/getHost"));
var _getPort = _interopRequireDefault(require("../../common-scripts/getPort"));
var _sanitizeMetafile = _interopRequireWildcard(require("../utils/sanitizeMetafile"));
var _getModularRoot = _interopRequireDefault(require("../../../utils/getModularRoot"));
var _rewriteDependenciesPlugin = require("../plugins/rewriteDependenciesPlugin");
var _createEsbuildBrowserslistTarget = _interopRequireDefault(require("../../common-scripts/createEsbuildBrowserslistTarget"));
var _formatPath = require("../utils/formatPath");
var _getLocation = _interopRequireDefault(require("../../../utils/getLocation"));
var _determineTargetPaths = _interopRequireDefault(require("../../common-scripts/determineTargetPaths"));
var _getHttpsConfig = require("../../common-scripts/getHttpsConfig");
var _generateSelfSignedCert = require("../utils/generateSelfSignedCert");
function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }
function _getRequireWildcardCache(nodeInterop) { if (typeof WeakMap !== "function") return null; var cacheBabelInterop = new WeakMap(); var cacheNodeInterop = new WeakMap(); return (_getRequireWildcardCache = function (nodeInterop) { return nodeInterop ? cacheNodeInterop : cacheBabelInterop; })(nodeInterop); }
function _interopRequireWildcard(obj, nodeInterop) { if (!nodeInterop && obj && obj.__esModule) { return obj; } if (obj === null || typeof obj !== "object" && typeof obj !== "function") { return { default: obj }; } var cache = _getRequireWildcardCache(nodeInterop); if (cache && cache.has(obj)) { return cache.get(obj); } var newObj = {}; var hasPropertyDescriptor = Object.defineProperty && Object.getOwnPropertyDescriptor; for (var key in obj) { if (key !== "default" && Object.prototype.hasOwnProperty.call(obj, key)) { var desc = hasPropertyDescriptor ? Object.getOwnPropertyDescriptor(obj, key) : null; if (desc && (desc.get || desc.set)) { Object.defineProperty(newObj, key, desc); } else { newObj[key] = obj[key]; } } } newObj.default = obj; if (cache) { cache.set(obj, newObj); } return newObj; }
const RUNTIME_DIR = path.join(__dirname, 'runtime');
class DevServer {
  watching = false;
  constructor({
    paths,
    urls,
    host,
    port,
    isApp,
    importInfo,
    useReactCreateRoot,
    styleImports
  }) {
    this.paths = paths;
    this.urls = urls;
    this.host = host;
    this.port = port;
    this.isApp = isApp;
    this.importInfo = importInfo;
    this.useReactCreateRoot = useReactCreateRoot;
    this.styleImports = styleImports;
    this.firstCompilePromise = new Promise(resolve => {
      this.firstCompilePromiseResolve = resolve;
    });
    this.env = (0, _getClientEnvironment.default)(paths.publicUrlOrPath.slice(0, -1));
    this.express = express.default();
    this.express.use(this.handleStaticAsset);
    this.isApp || this.express.get('/static/js/_trampoline.js', this.handleTrampoline);
    this.express.use('/static/js', this.handleStaticAsset);
    this.express.use(this.handleRuntimeAsset);
    this.express.use(express.static(paths.appPublic, {
      cacheControl: false,
      index: false
    }));

    // eslint-disable-next-line @typescript-eslint/no-misused-promises
    this.express.get('/', this.handleIndex);
    this.express.use((0, _errorOverlayMiddleware.default)());

    // This registers user provided middleware for proxy reasons
    if (fs.existsSync(paths.proxySetup)) {
      // eslint-disable-next-line @typescript-eslint/no-unsafe-call, @typescript-eslint/no-var-requires
      require(paths.proxySetup)(this.express);
    }
  }
  async start(targetDir) {
    // force clearing the terminal when we start a dev server process
    // unless we're in CI because we'll want to keep all logs
    logger.clear();
    logger.log(_chalk.default.cyan('Starting the development server...\n'));
    const modularRoot = (0, _getModularRoot.default)();
    const {
      SSL_CRT_FILE,
      SSL_KEY_FILE,
      HTTPS
    } = process.env;
    const isHttps = HTTPS === 'true';
    if (isHttps) {
      let key;
      let cert;
      let keyPath;
      let certPath;

      // If the user has supplied the key and cert files, use those instead
      if (SSL_KEY_FILE && SSL_CRT_FILE) {
        keyPath = path.resolve(targetDir, SSL_KEY_FILE);
        certPath = path.resolve(targetDir, SSL_CRT_FILE);
        try {
          // 1. Package path (for webpack compatibility)
          key = (0, _getHttpsConfig.readEnvFile)(keyPath, SSL_KEY_FILE);
          cert = (0, _getHttpsConfig.readEnvFile)(certPath, SSL_CRT_FILE);
        } catch (e) {
          // 2. Modular root
          keyPath = path.resolve(modularRoot, SSL_KEY_FILE);
          certPath = path.resolve(modularRoot, SSL_CRT_FILE);
          key = (0, _getHttpsConfig.readEnvFile)(keyPath, SSL_KEY_FILE);
          cert = (0, _getHttpsConfig.readEnvFile)(certPath, SSL_CRT_FILE);
        }
        (0, _getHttpsConfig.validateKeyAndCerts)({
          key,
          cert,
          keyPath,
          certPath
        });
      } else {
        // By default, use a self-signed, generated cert
        const selfSignedCert = await (0, _generateSelfSignedCert.generateSelfSignedCert)();
        key = selfSignedCert;
        cert = selfSignedCert;
      }
      this.server = https.createServer({
        key,
        cert
      }, this.express).listen(this.port, this.host);
    } else {
      this.server = http.createServer(this.express).listen(this.port, this.host);
    }
    this.ws = (0, _expressWs.default)(this.express, this.server);
    this.ws.app.ws('/_ws', (ws, req) => {
      logger.debug('Connected');
    });

    // Start esbuild after starting the server.
    // This order is important, since `this.ws` is only set
    // after https has been determined and the server has been booted.
    await this.startEsbuildServer();
    await this.hostRuntime();
    await (0, _openBrowser.default)(this.urls.localUrlForBrowser);
    return new Promise(resolve => resolve(this));
  }
  shutdown = () => {
    var _this$ws, _this$server, _this$esbuildContext;
    (_this$ws = this.ws) === null || _this$ws === void 0 ? void 0 : _this$ws.getWss().close();
    (_this$server = this.server) === null || _this$server === void 0 ? void 0 : _this$server.close();
    process.nextTick(() => {
      var _this$ws2;
      (_this$ws2 = this.ws) === null || _this$ws2 === void 0 ? void 0 : _this$ws2.getWss().clients.forEach(socket => {
        socket.terminate();
      });
    });
    void ((_this$esbuildContext = this.esbuildContext) === null || _this$esbuildContext === void 0 ? void 0 : _this$esbuildContext.dispose());
  };
  hostRuntime = (0, _memoize.default)(async () => {
    const runtimeDirFiles = await fs.readdir(RUNTIME_DIR);
    const indexFiles = runtimeDirFiles.filter(p => p.startsWith('index') && ['.js', '.ts'].some(extension => p.endsWith(extension)));
    if (indexFiles.length !== 1) {
      throw new Error(`Found multiple possible entry files`);
    }
    const entryPoint = indexFiles[0];
    this.runtimeEsbuild = await esbuild.build({
      entryPoints: [path.join(RUNTIME_DIR, entryPoint)],
      bundle: true,
      format: 'esm',
      target: 'es2015',
      logLevel: 'silent',
      define: {
        global: 'window'
      },
      banner: {
        js: `window.process = {
          platform: '${process.platform}',
          env: { NODE_ENV: 'developement' },
        }`
      },
      write: false,
      outbase: RUNTIME_DIR,
      absWorkingDir: (0, _getModularRoot.default)(),
      outdir: path.join(RUNTIME_DIR, '_runtime')
    });
  });
  baseEsbuildConfig = (0, _memoize.default)(() => {
    const browserTarget = (0, _createEsbuildBrowserslistTarget.default)(this.paths.appPath);
    let plugins;
    if (!this.isApp && this.importInfo) {
      plugins = [(0, _rewriteDependenciesPlugin.createRewriteDependenciesPlugin)(this.importInfo)];
    }
    return (0, _createEsbuildConfig.default)(this.paths, {
      write: false,
      minify: false,
      entryNames: 'static/js/[name]',
      chunkNames: 'static/js/[name]',
      assetNames: 'static/media/[name]',
      target: browserTarget,
      plugins
    });
  });
  runEsbuild = async () => {
    return esbuild.build(this.baseEsbuildConfig());
  };
  metafileCallback = metafile => {
    if (metafile) {
      this.metafile = (0, _sanitizeMetafile.default)(this.paths, metafile);
    }
  };
  firstCompilePluginCallback = () => {
    var _this$firstCompilePro;
    (_this$firstCompilePro = this.firstCompilePromiseResolve) === null || _this$firstCompilePro === void 0 ? void 0 : _this$firstCompilePro.call(this);
  };
  onRebuildCallback = result => {
    if (result) {
      this.esbuildResult = result;
    }
  };
  watchEsbuild = async () => {
    var _config$plugins, _config$plugins2, _config$plugins4, _config$plugins5;
    const config = this.baseEsbuildConfig();
    (_config$plugins = config.plugins) === null || _config$plugins === void 0 ? void 0 : _config$plugins.push((0, _incrementalReporter.default)(this.paths));
    (_config$plugins2 = config.plugins) === null || _config$plugins2 === void 0 ? void 0 : _config$plugins2.push((0, _incrementalCompile.default)(this.paths, this.urls));
    if (this.ws) {
      var _config$plugins3;
      (_config$plugins3 = config.plugins) === null || _config$plugins3 === void 0 ? void 0 : _config$plugins3.push((0, _wsReload.default)('app', this.ws.getWss(), this.paths));
    }
    (_config$plugins4 = config.plugins) === null || _config$plugins4 === void 0 ? void 0 : _config$plugins4.push((0, _metafileReporter.default)(this.metafileCallback));
    (_config$plugins5 = config.plugins) === null || _config$plugins5 === void 0 ? void 0 : _config$plugins5.push((0, _firstCompile.default)(this.firstCompilePluginCallback, this.onRebuildCallback));
    this.esbuildContext = await esbuild.context(config);
    void this.esbuildContext.watch();
  };
  startEsbuildServer = async () => {
    if (!this.watching) {
      this.watching = true;
    }
    await this.runEsbuild();

    // if the non-incremental succeeds then
    // we start a watching server
    await this.watchEsbuild();
    return this.firstCompilePromise;
  };
  handleIndex = async (_, res) => {
    // wait until the first watch compile is complete
    await this.firstCompilePromise;
    res.writeHead(200);
    res.end(await (0, _api.createStartIndex)({
      paths: this.paths,
      metafile: this.metafile,
      replacements: this.env.raw,
      styleImports: this.styleImports,
      isApp: this.isApp
    }));
  };
  handleTrampoline = (_, res) => {
    res.setHeader('content-type', 'application/javascript');
    res.writeHead(200);
    const trampolineBuildResult = (0, _api.createViewTrampoline)({
      fileName: 'index.js',
      importInfo: this.importInfo,
      useReactCreateRoot: this.useReactCreateRoot
    });
    res.end(trampolineBuildResult);
  };
  serveEsbuild = (outputDirectory, url, result, res, next) => {
    const outputFiles = result.outputFiles || [];
    for (const file of outputFiles) {
      if ((0, _formatPath.normalizeToPosix)((0, _sanitizeMetafile.sanitizeFileName)('/' + path.relative(outputDirectory, file.path))) === url) {
        const type = (0, _mime.getType)(url);
        res.setHeader('Content-Type', type);
        res.writeHead(200);
        return res.end(file.text);
      }
    }
    next();
  };
  handleStaticAsset = async (req, res, next) => {
    // wait until the first watch compile is complete
    await this.firstCompilePromise;
    if (this.esbuildResult) {
      this.serveEsbuild(this.baseEsbuildConfig().outdir, req.url, this.esbuildResult, res, next);
    }
  };
  handleRuntimeAsset = (req, res, next) => {
    this.serveEsbuild(RUNTIME_DIR, req.url, this.runtimeEsbuild, res, next);
  };
}
async function startEsbuild({
  target,
  isApp,
  importInfo,
  useReactCreateRoot,
  styleImports
}) {
  const targetPath = await (0, _getLocation.default)(target);
  const paths = (0, _determineTargetPaths.default)(target, targetPath);
  const host = (0, _getHost.default)();
  const port = await (0, _getPort.default)(host);
  const urls = (0, _urls.default)(process.env.HTTPS === 'true' ? 'https' : 'http', host, port, paths.publicUrlOrPath.slice(0, -1));
  const targetDir = await (0, _getLocation.default)(target);
  const devServer = new DevServer({
    paths,
    urls,
    host,
    port,
    isApp,
    importInfo,
    useReactCreateRoot,
    styleImports
  });
  const server = await devServer.start(targetDir);
  ['SIGINT', 'SIGTERM'].forEach(sig => {
    process.on(sig, () => {
      void server.shutdown();
      process.exit();
    });
  });
  if (!_isCi.default) {
    // Gracefully exit when stdin ends
    process.stdin.on('end', () => {
      void server.shutdown();
      process.exit();
    });
  }
}
//# sourceMappingURL=index.js.map