"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = void 0;
var _chalk = _interopRequireDefault(require("chalk"));
var fs = _interopRequireWildcard(require("fs-extra"));
var logger = _interopRequireWildcard(require("../../../../utils/logger"));
function _getRequireWildcardCache(nodeInterop) { if (typeof WeakMap !== "function") return null; var cacheBabelInterop = new WeakMap(); var cacheNodeInterop = new WeakMap(); return (_getRequireWildcardCache = function (nodeInterop) { return nodeInterop ? cacheNodeInterop : cacheBabelInterop; })(nodeInterop); }
function _interopRequireWildcard(obj, nodeInterop) { if (!nodeInterop && obj && obj.__esModule) { return obj; } if (obj === null || typeof obj !== "object" && typeof obj !== "function") { return { default: obj }; } var cache = _getRequireWildcardCache(nodeInterop); if (cache && cache.has(obj)) { return cache.get(obj); } var newObj = {}; var hasPropertyDescriptor = Object.defineProperty && Object.getOwnPropertyDescriptor; for (var key in obj) { if (key !== "default" && Object.prototype.hasOwnProperty.call(obj, key)) { var desc = hasPropertyDescriptor ? Object.getOwnPropertyDescriptor(obj, key) : null; if (desc && (desc.get || desc.set)) { Object.defineProperty(newObj, key, desc); } else { newObj[key] = obj[key]; } } } newObj.default = obj; if (cache) { cache.set(obj, newObj); } return newObj; }
function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }
function createPlugin(paths, urls) {
  const plugin = {
    name: 'incremental-logging',
    async setup(build) {
      const packageJsonText = await fs.readFile(paths.appPackageJson, {
        encoding: 'utf-8'
      });
      const packageJson = JSON.parse(packageJsonText);
      const appName = packageJson.name;
      let buildCounter = 0;
      const buildCountMap = new Map();
      build.onStart(() => {
        buildCounter += 1;
        buildCountMap.set(buildCounter, new Date());
        logger.clear();
        logger.log(_chalk.default.yellow('Compiling...'));
      });
      build.onEnd(result => {
        const buildStartTime = buildCountMap.get(buildCounter);

        // clean up before we have a memory leak...
        buildCountMap.delete(buildCounter);
        const buildTime = Number(new Date()) - Number(buildStartTime);
        logger.clear();
        const isSuccessful = !result.errors.length && !result.warnings.length;
        if (isSuccessful) {
          logger.log(`${_chalk.default.green('Compiled successfully!')} ${_chalk.default.dim(`[${buildTime}ms]`)}`);
          logger.log();
          logger.log(`You can now view ${_chalk.default.bold(appName)} in the browser.`);
          logger.log();
          if (urls.lanUrlForTerminal) {
            logger.log(`  ${_chalk.default.bold('Local:')}            ${urls.localUrlForTerminal}`);
            logger.log(`  ${_chalk.default.bold('On Your Network:')}  ${urls.lanUrlForTerminal}`);
          } else {
            logger.log(`  ${urls.localUrlForTerminal}`);
          }
          logger.log();
        }
      });
    }
  };
  return plugin;
}
var _default = createPlugin;
exports.default = _default;
//# sourceMappingURL=incrementalCompile.js.map