"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = createPlugin;
var _formatError = require("../../utils/formatError");
function createPlugin(name, server, paths) {
  const plugin = {
    name: 'ws-reload',
    setup(build) {
      let building = false;
      let result;
      const publishClient = async socket => {
        socket.send(JSON.stringify({
          name,
          building,
          result: {
            errors: await Promise.all(result.errors.map(error => (0, _formatError.formatError)(error, paths.modularRoot))),
            warnings: await Promise.all(result.warnings.map(warning => (0, _formatError.formatError)(warning, paths.modularRoot)))
          }
        }));
      };
      const publishAll = () => Promise.all(Array.from(server.clients).map(publishClient));
      server.on('connection', s => void publishClient(s));
      build.onStart(() => {
        building = true;
        void publishAll();
      });
      build.onEnd(_result => {
        building = false;
        result = _result;
        void publishAll();
      });
    }
  };
  return plugin;
}
//# sourceMappingURL=wsReload.js.map