"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.generateSelfSignedCert = generateSelfSignedCert;
var _fs = _interopRequireDefault(require("fs"));
var _path = _interopRequireDefault(require("path"));
var _util = require("util");
var _selfsigned = _interopRequireDefault(require("selfsigned"));
var _rimraf = _interopRequireDefault(require("rimraf"));
var logger = _interopRequireWildcard(require("../../../utils/logger"));
function _getRequireWildcardCache(nodeInterop) { if (typeof WeakMap !== "function") return null; var cacheBabelInterop = new WeakMap(); var cacheNodeInterop = new WeakMap(); return (_getRequireWildcardCache = function (nodeInterop) { return nodeInterop ? cacheNodeInterop : cacheBabelInterop; })(nodeInterop); }
function _interopRequireWildcard(obj, nodeInterop) { if (!nodeInterop && obj && obj.__esModule) { return obj; } if (obj === null || typeof obj !== "object" && typeof obj !== "function") { return { default: obj }; } var cache = _getRequireWildcardCache(nodeInterop); if (cache && cache.has(obj)) { return cache.get(obj); } var newObj = {}; var hasPropertyDescriptor = Object.defineProperty && Object.getOwnPropertyDescriptor; for (var key in obj) { if (key !== "default" && Object.prototype.hasOwnProperty.call(obj, key)) { var desc = hasPropertyDescriptor ? Object.getOwnPropertyDescriptor(obj, key) : null; if (desc && (desc.get || desc.set)) { Object.defineProperty(newObj, key, desc); } else { newObj[key] = obj[key]; } } } newObj.default = obj; if (cache) { cache.set(obj, newObj); } return newObj; }
function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }
const del = (0, _util.promisify)(_rimraf.default);

// This code is mostly duplicated from webpack-dev-server, with some typings added.
// To provide consistent https behaviour in esbuild mode, we use the same directories to store the generated cert.
// See: https://github.com/webpack/webpack-dev-server/blob/master/lib/Server.js

function findCacheDir() {
  const cwd = process.cwd();
  let dir = cwd;
  for (;;) {
    try {
      if (_fs.default.statSync(_path.default.join(dir, 'package.json')).isFile()) break;
    } catch (e) {}
    const parent = _path.default.dirname(dir);
    if (dir === parent) {
      dir = undefined;
      break;
    }
    dir = parent;
  }
  if (!dir) {
    return _path.default.resolve(cwd, '.cache/webpack-dev-server');
  } else if (process.versions.pnp === '1') {
    return _path.default.resolve(dir, '.pnp/.cache/webpack-dev-server');
  } else if (process.versions.pnp === '3') {
    return _path.default.resolve(dir, '.yarn/.cache/webpack-dev-server');
  }
  return _path.default.resolve(dir, 'node_modules/.cache/webpack-dev-server');
}
async function generateSelfSignedCert() {
  const certificateDir = findCacheDir();
  const certificatePath = _path.default.join(certificateDir, 'server.pem');
  let certificateExists = _fs.default.existsSync(certificatePath);
  if (certificateExists) {
    const certificateTtl = 1000 * 60 * 60 * 24;
    const certificateStat = _fs.default.statSync(certificatePath);
    const now = new Date();

    // cert is more than 30 days old, kill it with fire
    if ((Number(now) - Number(certificateStat.ctime)) / certificateTtl > 30) {
      logger.log('SSL Certificate is more than 30 days old. Removing...');
      await del(certificatePath);
      certificateExists = false;
    }
  }
  if (!certificateExists) {
    logger.log('Generating SSL Certificate...');
    const attributes = [{
      name: 'commonName',
      value: 'localhost'
    }];
    const pems = _selfsigned.default.generate(attributes, {
      algorithm: 'sha256',
      days: 30,
      keySize: 2048,
      extensions: [{
        name: 'basicConstraints',
        cA: true
      }, {
        name: 'keyUsage',
        keyCertSign: true,
        digitalSignature: true,
        nonRepudiation: true,
        keyEncipherment: true,
        dataEncipherment: true
      }, {
        name: 'extKeyUsage',
        serverAuth: true,
        clientAuth: true,
        codeSigning: true,
        timeStamping: true
      }, {
        name: 'subjectAltName',
        altNames: [{
          // type 2 is DNS
          type: 2,
          value: 'localhost'
        }, {
          type: 2,
          value: 'localhost.localdomain'
        }, {
          type: 2,
          value: 'lvh.me'
        }, {
          type: 2,
          value: '*.lvh.me'
        }, {
          type: 2,
          value: '[::1]'
        }, {
          // type 7 is IP
          type: 7,
          ip: '127.0.0.1'
        }, {
          type: 7,
          ip: 'fe80::1'
        }]
      }]
    });
    _fs.default.mkdirSync(certificateDir, {
      recursive: true
    });
    _fs.default.writeFileSync(certificatePath, pems.private + pems.cert, {
      encoding: 'utf8'
    });
  }
  const fakeCert = _fs.default.readFileSync(certificatePath);
  logger.log(`SSL certificate: ${certificatePath}`);
  return fakeCert;
}
//# sourceMappingURL=generateSelfSignedCert.js.map