"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.createEsbuildAssets = createEsbuildAssets;
exports.esbuildMeasureFileSizesBeforeBuild = esbuildMeasureFileSizesBeforeBuild;
var path = _interopRequireWildcard(require("path"));
var fs = _interopRequireWildcard(require("fs-extra"));
var _gzipSize = require("gzip-size");
var _recursiveReaddir = _interopRequireDefault(require("recursive-readdir"));
var _getModularRoot = _interopRequireDefault(require("../utils/getModularRoot"));
var _fileSizeReporter = require("./fileSizeReporter");
function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }
function _getRequireWildcardCache(nodeInterop) { if (typeof WeakMap !== "function") return null; var cacheBabelInterop = new WeakMap(); var cacheNodeInterop = new WeakMap(); return (_getRequireWildcardCache = function (nodeInterop) { return nodeInterop ? cacheNodeInterop : cacheBabelInterop; })(nodeInterop); }
function _interopRequireWildcard(obj, nodeInterop) { if (!nodeInterop && obj && obj.__esModule) { return obj; } if (obj === null || typeof obj !== "object" && typeof obj !== "function") { return { default: obj }; } var cache = _getRequireWildcardCache(nodeInterop); if (cache && cache.has(obj)) { return cache.get(obj); } var newObj = {}; var hasPropertyDescriptor = Object.defineProperty && Object.getOwnPropertyDescriptor; for (var key in obj) { if (key !== "default" && Object.prototype.hasOwnProperty.call(obj, key)) { var desc = hasPropertyDescriptor ? Object.getOwnPropertyDescriptor(obj, key) : null; if (desc && (desc.get || desc.set)) { Object.defineProperty(newObj, key, desc); } else { newObj[key] = obj[key]; } } } newObj.default = obj; if (cache) { cache.set(obj, newObj); } return newObj; }
function removeFileNameHash(fileName) {
  return fileName.replace(/\\/g, '/').replace(/\/?(.*)(\.chunk)?(\.[0-9a-f]+)(\.js|\.css)/, (_match, p1, _p2, _p3, p4) => p1 + p4);
}
function esbuildMeasureFileSizesBeforeBuild(buildFolder) {
  const modularRoot = (0, _getModularRoot.default)();
  return new Promise(resolve => {
    (0, _recursiveReaddir.default)(buildFolder, (err, fileNames) => {
      if (err) {
        resolve({});
      } else {
        resolve(fileNames.filter(_fileSizeReporter.canReadAsset).reduce((memo, absoluteFilePath) => {
          const filePath = path.relative(modularRoot, absoluteFilePath);
          const contents = fs.readFileSync(absoluteFilePath);
          const folder = path.dirname(filePath);
          const name = path.basename(filePath);
          const key = `${folder}/${removeFileNameHash(name)}`;
          memo[key] = (0, _gzipSize.sync)(contents);
          return memo;
        }, {}));
      }
    });
  });
}
function createEsbuildAssets(stats) {
  const modularRoot = (0, _getModularRoot.default)();
  const readableAssets = Object.keys(stats.outputs).filter(_fileSizeReporter.canReadAsset);
  return readableAssets.map(filePath => {
    const fileContents = fs.readFileSync(path.join(modularRoot, filePath));
    const size = (0, _gzipSize.sync)(fileContents);
    const folder = path.dirname(filePath);
    const name = path.basename(filePath);
    return {
      folder,
      name,
      normalizedName: `${folder}/${removeFileNameHash(name)}`,
      size: size
    };
  }).sort((a, b) => b.size - a.size);
}
//# sourceMappingURL=esbuildFileSizeReporter.js.map