"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = buildWebpack;
var _isCi = _interopRequireDefault(require("is-ci"));
var _chalk = _interopRequireDefault(require("chalk"));
var _webpack = _interopRequireDefault(require("webpack"));
var _formatWebpackMessages = _interopRequireDefault(require("./utils/formatWebpackMessages"));
var _printBuildError = _interopRequireDefault(require("./utils/printBuildError"));
var _logger = require("../../utils/logger");
var _webpack2 = _interopRequireDefault(require("./config/webpack.config"));
function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }
async function buildWebpack(target, esbuildTargetFactory, isApp, importInfo, useReactCreateRoot, styleImports, paths) {
  const webpackConfig = await (0, _webpack2.default)(target, true, esbuildTargetFactory, isApp, importInfo, useReactCreateRoot, styleImports, paths);
  const compiler = (0, _webpack.default)(webpackConfig);
  return await runCompiler(compiler);
}
async function runCompiler(compiler) {
  return new Promise((resolve, reject) => {
    compiler.run((err, stats) => {
      (0, _logger.log)('Webpack Compiled.');
      let messages;
      let statsJson;
      if (err) {
        if (err.message) {
          (0, _printBuildError.default)(err);
          reject();
        }
        messages = (0, _formatWebpackMessages.default)({
          errors: [err],
          warnings: []
        });
      } else if (stats) {
        statsJson = stats.toJson();
        messages = (0, _formatWebpackMessages.default)({
          errors: statsJson.errors,
          warnings: statsJson.warnings
        });
      }
      if (messages && messages.errors.length) {
        // Only keep the first error. Others are often indicative
        // of the same problem, but confuse the reader with noise.
        (0, _printBuildError.default)(new Error(messages.errors[0]));
        reject();
      }
      if (_isCi.default && messages && messages.warnings.length) {
        (0, _logger.log)(_chalk.default.yellow('Treating warnings as errors because process.env.CI = true.\n' + 'Most CI servers set it automatically.\n'));
        (0, _printBuildError.default)(new Error(messages.warnings.join('\n\n')));
        reject();
      }
      statsJson ? resolve(statsJson) : reject();
    });
  });
}
//# sourceMappingURL=buildWebpack.js.map