"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.createAppConfig = createAppConfig;
exports.createAppPluginConfig = createAppPluginConfig;
var _htmlWebpackPlugin = _interopRequireDefault(require("html-webpack-plugin"));
var _InlineChunkHtmlPlugin = _interopRequireDefault(require("../../plugins/InlineChunkHtmlPlugin"));
var _InterpolateHtmlPlugin = _interopRequireDefault(require("../../plugins/InterpolateHtmlPlugin"));
function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }
function createAppConfig() {
  return {
    optimization: {
      // Automatically split vendor and commons
      splitChunks: {
        chunks: 'all'
      },
      // Keep the runtime chunk separated to enable long term caching
      // https://twitter.com/wSokra/status/969679223278505985
      // https://github.com/facebook/create-react-app/issues/5358
      runtimeChunk: {
        name: entrypoint => `runtime-${entrypoint.name}`
      }
    }
  };
}
function createAppPluginConfig(isEnvProduction, shouldInlineRuntimeChunk, env, paths) {
  return {
    plugins: [
    // Generates an `index.html` file with the <script> injected.
    new _htmlWebpackPlugin.default(Object.assign({}, {
      inject: true,
      template: paths.appHtml
    }, isEnvProduction ? {
      minify: {
        removeComments: true,
        collapseWhitespace: true,
        removeRedundantAttributes: true,
        useShortDoctype: true,
        removeEmptyAttributes: true,
        removeStyleLinkTypeAttributes: true,
        keepClosingSlash: true,
        minifyJS: true,
        minifyCSS: true,
        minifyURLs: true
      }
    } : undefined)) // 'as unknown' used as Workaround for Typescript unable to compare the types
    // 'due to excessive stack depth' in current Typescript version 4.8.3
    ,
    // Inlines the webpack runtime script. This script is too small to warrant
    // a network request.
    // https://github.com/facebook/create-react-app/issues/5358
    isEnvProduction && shouldInlineRuntimeChunk && new _InlineChunkHtmlPlugin.default(_htmlWebpackPlugin.default, [/runtime-.+[.]js/]),
    // Makes some environment variables available in index.html.
    // The public URL is available as %PUBLIC_URL% in index.html, e.g.:
    // <link rel="icon" href="%PUBLIC_URL%/favicon.ico">
    // It will be an empty string unless you specify "homepage"
    // in `package.json`, in which case it will be the pathname of that URL.
    new _InterpolateHtmlPlugin.default(_htmlWebpackPlugin.default, env.raw)].filter(Boolean)
  };
}
//# sourceMappingURL=appConfig.js.map