"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = startWebpack;
var _fs = _interopRequireDefault(require("fs"));
var _chalk = _interopRequireDefault(require("chalk"));
var _webpackDevServer = _interopRequireDefault(require("webpack-dev-server"));
var _isCi = _interopRequireDefault(require("is-ci"));
var _fsExtra = require("fs-extra");
var _webpack = _interopRequireDefault(require("./config/webpack.config"));
var _webpackDevServer2 = _interopRequireDefault(require("./config/webpackDevServer.config"));
var _logger = require("../../utils/logger");
var _webpackDevServerUtils = require("./utils/webpackDevServerUtils");
var _getPort = require("../common-scripts/getPort");
var _urls = _interopRequireDefault(require("../common-scripts/urls"));
var _openBrowser = _interopRequireDefault(require("../common-scripts/openBrowser"));
function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }
// Tools like Cloud9 rely on this.
const portEnv = process.env.PORT;
const DEFAULT_PORT = portEnv ? parseInt(portEnv, 10) : 3000;
const HOST = process.env.HOST || '0.0.0.0';
function startWebpack(target, esbuildTargetFactory, isApp, importInfo, useReactCreateRoot, styleImports, paths) {
  if (process.env.HOST) {
    (0, _logger.log)(_chalk.default.cyan(`Attempting to bind to HOST environment variable: ${_chalk.default.yellow(_chalk.default.bold(process.env.HOST))}`));
    (0, _logger.log)(`If this was unintentional, check that you haven't mistakenly set it in your shell.`);
    (0, _logger.log)(`Learn more here: ${_chalk.default.yellow('https://cra.link/advanced-config')}`);
    (0, _logger.log)();
  }
  (0, _getPort.choosePort)(HOST, DEFAULT_PORT).then(async port => {
    if (!port) {
      // We have not found a port.
      return;
    }
    const config = await (0, _webpack.default)(target, false, esbuildTargetFactory, isApp, importInfo, useReactCreateRoot, styleImports, paths);
    // overload for webpack-dev-server@4
    config.stats = 'none';
    config.infrastructureLogging = {
      level: 'none'
    };
    const protocol = process.env.HTTPS === 'true' ? 'https' : 'http';
    const packageJson = (0, _fsExtra.readJSONSync)(require.resolve(paths.appPackageJson));
    const appName = packageJson.name;
    const useTypeScript = !_isCi.default && _fs.default.existsSync(paths.appTsConfig);
    const urls = (0, _urls.default)(protocol, HOST, port, paths.publicUrlOrPath.slice(0, -1));
    // Create a webpack compiler that is configured with custom messages.
    // Only run typecheck if not in CI env
    const compiler = (0, _webpackDevServerUtils.createCompiler)(appName, config, urls, useTypeScript);

    // Load proxy config
    const proxySetting = packageJson.proxy;
    const proxyConfig = (0, _webpackDevServerUtils.prepareProxy)(proxySetting, paths.appPublic, paths.publicUrlOrPath);
    // Serve webpack assets generated by the compiler over a web server.
    const serverConfig = (0, _webpackDevServer2.default)(port, proxyConfig, urls.lanUrlForConfig, paths);

    // Types from WebpackDevServer and Webpack overlap but unfortunately aren't compatible
    // even though when you look into it Webpack-Dev-Server simply imports the Webpack types
    const devServer = new _webpackDevServer.default(serverConfig, compiler);

    // Launch WebpackDevServer.
    (0, _logger.log)(_chalk.default.cyan('Starting the development server...'));
    await devServer.start();
    void (0, _openBrowser.default)(urls.localUrlForBrowser);
    ['SIGINT', 'SIGTERM'].forEach(function (sig) {
      process.on(sig, function () {
        devServer.close();
        return;
      });
    });

    // Gracefully exit when stdin ends
    process.stdin.on('end', function () {
      devServer.close();
      return;
    });
  }).catch(err => {
    if (err && err.message) {
      (0, _logger.log)(err.message);
    }
  });
}
//# sourceMappingURL=startWebpack.js.map