"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.check = check;
exports.fix = fix;
var path = _interopRequireWildcard(require("path"));
var _browserslist = _interopRequireDefault(require("browserslist"));
var _chalk = _interopRequireDefault(require("chalk"));
var fs = _interopRequireWildcard(require("fs-extra"));
var _prompts = _interopRequireDefault(require("prompts"));
var logger = _interopRequireWildcard(require("../utils/logger"));
var _getModularRoot = _interopRequireDefault(require("../utils/getModularRoot"));
var _getWorkspaceInfo = _interopRequireDefault(require("../utils/getWorkspaceInfo"));
var _checkBrowsers = require("../utils/checkBrowsers");
function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }
function _getRequireWildcardCache(nodeInterop) { if (typeof WeakMap !== "function") return null; var cacheBabelInterop = new WeakMap(); var cacheNodeInterop = new WeakMap(); return (_getRequireWildcardCache = function (nodeInterop) { return nodeInterop ? cacheNodeInterop : cacheBabelInterop; })(nodeInterop); }
function _interopRequireWildcard(obj, nodeInterop) { if (!nodeInterop && obj && obj.__esModule) { return obj; } if (obj === null || typeof obj !== "object" && typeof obj !== "function") { return { default: obj }; } var cache = _getRequireWildcardCache(nodeInterop); if (cache && cache.has(obj)) { return cache.get(obj); } var newObj = {}; var hasPropertyDescriptor = Object.defineProperty && Object.getOwnPropertyDescriptor; for (var key in obj) { if (key !== "default" && Object.prototype.hasOwnProperty.call(obj, key)) { var desc = hasPropertyDescriptor ? Object.getOwnPropertyDescriptor(obj, key) : null; if (desc && (desc.get || desc.set)) { Object.defineProperty(newObj, key, desc); } else { newObj[key] = obj[key]; } } } newObj.default = obj; if (cache) { cache.set(obj, newObj); } return newObj; }
async function check(target) {
  let valid = true;
  _browserslist.default.clearCaches();
  const modularRoot = (0, _getModularRoot.default)();
  const workspace = await (0, _getWorkspaceInfo.default)(target);
  for (const [packageName, worktree] of Object.entries(workspace)) {
    if (worktree.type === 'app') {
      const current = _browserslist.default.loadConfig({
        path: path.join(modularRoot, worktree.location)
      });
      if (current) {
        logger.debug(`${packageName} has valid browserslist`);
      } else {
        logger.error(`${packageName} does not have browserslist set.`);
        valid = false;
      }
    }
  }
  return valid;
}
async function shouldSetBrowsers() {
  if (process.stdout.isTTY) {
    const answer = await (0, _prompts.default)({
      type: 'confirm',
      name: 'shouldSetBrowsers',
      message: _chalk.default.yellow("We're unable to detect target browsers.") + `\n\nWould you like to add the defaults to your Modular Root ${_chalk.default.bold('package.json')}?`,
      initial: true
    });
    return answer.shouldSetBrowsers;
  } else {
    return Promise.resolve(true);
  }
}
async function fix() {
  const modularRoot = (0, _getModularRoot.default)();
  const workspace = await (0, _getWorkspaceInfo.default)();
  for (const worktree of Object.values(workspace)) {
    _browserslist.default.clearCaches();
    if (worktree.type === 'app') {
      const current = _browserslist.default.loadConfig({
        path: path.join(modularRoot, worktree.location)
      });
      if (!current) {
        const shouldUpdateBrowser = await shouldSetBrowsers();
        if (shouldUpdateBrowser) {
          logger.log(`Setting target browsers in modular root ${(0, _getModularRoot.default)()}`);
          const filePath = path.join((0, _getModularRoot.default)(), 'package.json');
          const pkg = await fs.readJson(filePath);
          pkg['browserslist'] = _checkBrowsers.defaultBrowsers;
          await fs.writeJson(filePath, pkg, {
            spaces: 2
          });
          _browserslist.default.clearCaches();
          logger.log();
          logger.log(`${_chalk.default.green('Set target browsers:')} ${_chalk.default.cyan(JSON.stringify(_checkBrowsers.defaultBrowsers, null, 2))}`);
          logger.log();
        }
      }
    }
  }
}
//# sourceMappingURL=verifyBrowserslist.js.map