"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.check = check;
exports.isValidModularRootPackageJson = isValidModularRootPackageJson;
var path = _interopRequireWildcard(require("path"));
var fs = _interopRequireWildcard(require("fs-extra"));
var _getModularRoot = _interopRequireDefault(require("../utils/getModularRoot"));
var logger = _interopRequireWildcard(require("../utils/logger"));
function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }
function _getRequireWildcardCache(nodeInterop) { if (typeof WeakMap !== "function") return null; var cacheBabelInterop = new WeakMap(); var cacheNodeInterop = new WeakMap(); return (_getRequireWildcardCache = function (nodeInterop) { return nodeInterop ? cacheNodeInterop : cacheBabelInterop; })(nodeInterop); }
function _interopRequireWildcard(obj, nodeInterop) { if (!nodeInterop && obj && obj.__esModule) { return obj; } if (obj === null || typeof obj !== "object" && typeof obj !== "function") { return { default: obj }; } var cache = _getRequireWildcardCache(nodeInterop); if (cache && cache.has(obj)) { return cache.get(obj); } var newObj = {}; var hasPropertyDescriptor = Object.defineProperty && Object.getOwnPropertyDescriptor; for (var key in obj) { if (key !== "default" && Object.prototype.hasOwnProperty.call(obj, key)) { var desc = hasPropertyDescriptor ? Object.getOwnPropertyDescriptor(obj, key) : null; if (desc && (desc.get || desc.set)) { Object.defineProperty(newObj, key, desc); } else { newObj[key] = obj[key]; } } } newObj.default = obj; if (cache) { cache.set(obj, newObj); } return newObj; }
/**
 * @param rootPackageJson package.json object from the modular root
 * @returns Returns true if the packages directory is correctly included in `workspaces`, else false
 */
function checkWorkspaceHasPackages(rootPackageJson) {
  var _rootPackageJson$work, _rootPackageJson$work2;
  if (Array.isArray(rootPackageJson === null || rootPackageJson === void 0 ? void 0 : rootPackageJson.workspaces)) {
    return !!rootPackageJson.workspaces.includes('packages/**');
  }
  return !!(rootPackageJson !== null && rootPackageJson !== void 0 && (_rootPackageJson$work = rootPackageJson.workspaces) !== null && _rootPackageJson$work !== void 0 && (_rootPackageJson$work2 = _rootPackageJson$work.packages) !== null && _rootPackageJson$work2 !== void 0 && _rootPackageJson$work2.includes('packages/**'));
}
async function check() {
  const modularRoot = (0, _getModularRoot.default)(); // Implicitly checks whether modular.type === 'root'
  const rootPackageJsonPath = path.join(modularRoot, 'package.json');
  const rootPackageJson = await fs.readJSON(rootPackageJsonPath);
  if (!rootPackageJson.private) {
    logger.error(`Modular workspace roots must be marked as private`);
    return false;
  }
  if (!checkWorkspaceHasPackages(rootPackageJson)) {
    logger.error(`Modular workspaces must include "packages/**" to pick up any modular packages in the worktree`);
    return false;
  }
  logger.debug('Modular root is valid.');
  return true;
}
function isValidModularRootPackageJson(dir) {
  const packageJsonPath = path.join(dir, 'package.json');
  if (fs.existsSync(packageJsonPath)) {
    var _packageJson$modular;
    const packageJson = fs.readJsonSync(packageJsonPath);
    return ((_packageJson$modular = packageJson.modular) === null || _packageJson$modular === void 0 ? void 0 : _packageJson$modular.type) === 'root' && !!packageJson.private && checkWorkspaceHasPackages(packageJson);
  }
  return false;
}
//# sourceMappingURL=verifyModularRootPackageJson.js.map