"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.check = check;
var path = _interopRequireWildcard(require("path"));
var fs = _interopRequireWildcard(require("fs-extra"));
var yaml = _interopRequireWildcard(require("js-yaml"));
var logger = _interopRequireWildcard(require("../utils/logger"));
var _getModularRoot = _interopRequireDefault(require("../utils/getModularRoot"));
function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }
function _getRequireWildcardCache(nodeInterop) { if (typeof WeakMap !== "function") return null; var cacheBabelInterop = new WeakMap(); var cacheNodeInterop = new WeakMap(); return (_getRequireWildcardCache = function (nodeInterop) { return nodeInterop ? cacheNodeInterop : cacheBabelInterop; })(nodeInterop); }
function _interopRequireWildcard(obj, nodeInterop) { if (!nodeInterop && obj && obj.__esModule) { return obj; } if (obj === null || typeof obj !== "object" && typeof obj !== "function") { return { default: obj }; } var cache = _getRequireWildcardCache(nodeInterop); if (cache && cache.has(obj)) { return cache.get(obj); } var newObj = {}; var hasPropertyDescriptor = Object.defineProperty && Object.getOwnPropertyDescriptor; for (var key in obj) { if (key !== "default" && Object.prototype.hasOwnProperty.call(obj, key)) { var desc = hasPropertyDescriptor ? Object.getOwnPropertyDescriptor(obj, key) : null; if (desc && (desc.get || desc.set)) { Object.defineProperty(newObj, key, desc); } else { newObj[key] = obj[key]; } } } newObj.default = obj; if (cache) { cache.set(obj, newObj); } return newObj; }
async function check() {
  let valid = true;
  const modularRoot = (0, _getModularRoot.default)();
  const yarnRcPath = path.join(modularRoot, './.yarnrc.yml');
  if (fs.existsSync(yarnRcPath)) {
    try {
      const doc = yaml.load(await fs.readFile(yarnRcPath, 'utf8'), {
        onWarning: function (err) {
          console.log('YAML parsing error: ', err);
        },
        json: true,
        // JSON compat mode will overwrite dupe entries instead of throw an error.
        schema: yaml.FAILSAFE_SCHEMA
      });
      valid = doc.nodeLinker === 'node-modules';
      if (doc.nodeLinker !== 'node-modules') {
        logger.error('.yarnrc.yml file found where nodeLinker is not "node-modules"');
        valid = false;
      } else {
        logger.debug('Valid .yarnrc.yml file found with "nodeLinker: node-modules"');
      }
    } catch (error) {
      if (error instanceof Error) {
        logger.debug(`Received error ${error.message} when trying to check .yarnrc.yml file`);
      }
    }
    return valid;
  } else {
    return true;
  }
}
//# sourceMappingURL=verifyYarnRcYml.js.map