#!/usr/bin/env node
"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.program = void 0;
var fs = _interopRequireWildcard(require("fs-extra"));
var _isCi = _interopRequireDefault(require("is-ci"));
var _chalk = _interopRequireDefault(require("chalk"));
var _commander = _interopRequireWildcard(require("commander"));
var _jestOptions = require("./test/jestOptions");
var _actionPreflightCheck = _interopRequireDefault(require("./utils/actionPreflightCheck"));
var logger = _interopRequireWildcard(require("./utils/logger"));
var _options = require("./utils/options");
function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }
function _getRequireWildcardCache(nodeInterop) { if (typeof WeakMap !== "function") return null; var cacheBabelInterop = new WeakMap(); var cacheNodeInterop = new WeakMap(); return (_getRequireWildcardCache = function (nodeInterop) { return nodeInterop ? cacheNodeInterop : cacheBabelInterop; })(nodeInterop); }
function _interopRequireWildcard(obj, nodeInterop) { if (!nodeInterop && obj && obj.__esModule) { return obj; } if (obj === null || typeof obj !== "object" && typeof obj !== "function") { return { default: obj }; } var cache = _getRequireWildcardCache(nodeInterop); if (cache && cache.has(obj)) { return cache.get(obj); } var newObj = {}; var hasPropertyDescriptor = Object.defineProperty && Object.getOwnPropertyDescriptor; for (var key in obj) { if (key !== "default" && Object.prototype.hasOwnProperty.call(obj, key)) { var desc = hasPropertyDescriptor ? Object.getOwnPropertyDescriptor(obj, key) : null; if (desc && (desc.get || desc.set)) { Object.defineProperty(newObj, key, desc); } else { newObj[key] = obj[key]; } } } newObj.default = obj; if (cache) { cache.set(obj, newObj); } return newObj; }
const program = new _commander.default.Command('modular');
exports.program = program;
program.version(fs.readJsonSync(require.resolve('modular-scripts/package.json')).version);
program.command('add').description(`Add a new package into the modular workspace.`).argument('[package-name]', 'Package name for the package.json').option('--unstable-type <type>', "Type of the package ('app', 'view', 'package')").option('--unstable-name <name>', 'Package name for the package.json').option('--template <name>', 'Template name').option('--path <targetPath>', 'Target root directory for the package').option('--prefer-offline', 'Equivalent of --prefer-offline for yarn installations', true).option('--verbose', 'Run yarn commands with --verbose set').action(async (packageName, addOptions) => {
  const {
    default: addPackage
  } = await Promise.resolve().then(() => _interopRequireWildcard(require('./addPackage')));
  return addPackage({
    name: packageName,
    type: addOptions.unstableType,
    template: addOptions.template,
    preferOffline: addOptions.preferOffline,
    verbose: addOptions.verbose,
    unstableName: addOptions.unstableName,
    path: addOptions.path
  });
});
program.command('analyze <package-name>').description(`Analyze the dependencies of a package.`).action(async packageName => {
  const {
    default: analyze
  } = await Promise.resolve().then(() => _interopRequireWildcard(require('./analyze')));
  return analyze({
    target: packageName
  });
});
program.command('build [packages...]').description('Build a list of packages (multiple package names can be supplied separated by space)').option('--preserve-modules [value]', 'Preserve module structure in generated modules', 'true').option('--verbose', 'Run yarn commands with --verbose set').option('--private', 'Enable the building of private packages', false).option('--changed', 'Build only for workspaces that have changed compared to the branch specified in --compareBranch', false).option('--descendants', 'Additionally build workspaces that the specified packages directly or indirectly depend on (can be combined with --changed)', false).option('--ancestors', 'Additionally build workspaces that directly or indirectly depend on the specified packages (can be combined with --changed)', false).option('--compareBranch <branch>', "Specifies the branch to use with the --changed flag. If not specified, Modular will use the repo's default branch").option('--dangerouslyIgnoreCircularDependencies', "Ignore circular dependency checks if your graph has one or more circular dependencies involving 'source' types, then warn. The build will still fail if circular dependencies involve more than one buildable package. Circular dependencies can be always refactored to remove cycles. This switch is dangerous and should be used sparingly and only temporarily.", false).option('--concurrencyLevel <level>', 'Limit the concurrency of build processes that are executed in parallel within batches. 0 or 1 means no concurrency. Default is the number of logical CPUs.').action(async (packagePaths, options) => {
  const {
    default: build
  } = await Promise.resolve().then(() => _interopRequireWildcard(require('./build-scripts')));
  (0, _options.validateCompareOptions)(options.compareBranch, options.changed);
  const concurrencyLevel = (0, _options.computeConcurrencyOption)(options.concurrencyLevel);
  logger.debug(`Running build with a concurrency level of ${concurrencyLevel}`);
  if (options.dangerouslyIgnoreCircularDependencies) {
    // Warn. Users should never use this, but if they use it, they should have cycles limited to "source" packages
    // and they should do this in a temporary way (for example, to onboard large projects).
    logger.warn(`You chose to dangerously ignore cycles in the dependency graph. Builds will still fail if a cycle is found involving two or more buildable packages. Please note that the use of this flag is not recommended. It's always possible to break a cyclic dependency by creating an additional dependency that contains the common code.`);
  }
  await build({
    packagePaths,
    preserveModules: JSON.parse(options.preserveModules),
    private: options.private,
    changed: options.changed,
    compareBranch: options.compareBranch,
    ancestors: options.ancestors,
    descendants: options.descendants,
    dangerouslyIgnoreCircularDependencies: options.dangerouslyIgnoreCircularDependencies,
    concurrencyLevel
  });
});
program.command('test [packages...]').option('--bypass', 'Bypass all modular specific selective behavior and pass all flags and options directly to Jest, except for --verbose, --swc & --env which can be used with --bypass. Ensures modular test behaves exactly like calling Jest directly, but with Modular configuration applied. Use with IntelliJ Jest configurations.', false).option('--swc', 'Use Rust based SWC Jest runner instead of ts-jest & babel for performance improvements', false).option('--ancestors', 'Additionally run tests for workspaces that depend on workspaces that have changed', false).option('--descendants', 'Additionally run tests for workspaces that directly or indirectly depend on the specified packages (can be combined with --changed)', false).option('--debug', 'Setup node.js debugger on the test process - equivalent of setting --inspect-brk on a node.js process', false).option('--changed', 'Run tests only for workspaces that have changed compared to the branch specified in --compareBranch').option('--compareBranch <branch>', "Specifies the branch to use with the --changed flag. If not specified, Modular will use the repo's default branch").option('--regex <regexes...>', 'Specifies one or more test name regular expression. When combined with selective options, it will run tests matching the regex as well as those matching the selective options').option('--coverage', _jestOptions.testOptions.coverage.description).option('--forceExit', _jestOptions.testOptions.forceExit.description).option('--env <env>', _jestOptions.testOptions.env.description, 'jsdom').option('--maxWorkers <workers>', _jestOptions.testOptions.maxWorkers.description).option('--onlyChanged', _jestOptions.testOptions.onlyChanged.description).option('--json', _jestOptions.testOptions.json.description).option('--outputFile <file>', _jestOptions.testOptions.outputFile.description).option('--reporters <reporters...>', _jestOptions.testOptions.reporters.description).option('--runInBand', _jestOptions.testOptions.runInBand.description).option('--silent', _jestOptions.testOptions.silent.description).option('--showConfig', _jestOptions.testOptions.showConfig.description).option('--testResultsProcessor <reporter>', _jestOptions.testOptions.testResultsProcessor.description).option('--updateSnapshot, -u', _jestOptions.testOptions.updateSnapshot.description).option('--verbose', _jestOptions.testOptions.verbose.description).option('--watch', _jestOptions.testOptions.watch.description).option('--watchAll [value]', _jestOptions.testOptions.watchAll.description, false).option('--bail [value]', _jestOptions.testOptions.bail.description, _isCi.default).option('--clearCache', _jestOptions.testOptions.clearCache.description).option('--logHeapUsage', _jestOptions.testOptions.logHeapUsage.description).option('--no-cache', _jestOptions.testOptions.cache.description).allowUnknownOption().description('Run tests over the codebase').action(async (packages, options) => {
  (0, _options.validateCompareOptions)(options.compareBranch, options.changed);
  const {
    default: test
  } = await Promise.resolve().then(() => _interopRequireWildcard(require('./test')));

  // proxy simplified options to testOptions
  const {
    U,
    ...testOptions
  } = options;
  testOptions.updateSnapshot = !!(options.updateSnapshot || U);
  return test(testOptions, packages);
});
program.command('start [packageName]').description(`Start a dev-server for an app. Only available for modular 'app' types.`).option('--verbose', 'Run yarn commands with --verbose set').action(async packageName => {
  const {
    default: start
  } = await Promise.resolve().then(() => _interopRequireWildcard(require('./start')));
  return start(packageName);
});
program.command('workspace').description('Retrieve the information for the current workspace info').action((0, _actionPreflightCheck.default)(async () => {
  const {
    default: getWorkspaceInfo
  } = await Promise.resolve().then(() => _interopRequireWildcard(require('./utils/getWorkspaceInfo')));
  const workspace = await getWorkspaceInfo();
  process.stdout.write(JSON.stringify(workspace, null, 2));
}));
program.command('check').description('Manually run modular checks against the current modular repository').option('--fix', 'Run autofixers which are available.').option('--verbose', 'Run yarn commands with --verbose set').action(async ({
  fix
}) => {
  const {
    check
  } = await Promise.resolve().then(() => _interopRequireWildcard(require('./check')));
  await check({
    fix
  });
  logger.log(_chalk.default.green('Success!'));
});
const lintStagedFlag = '--staged';
program.command('lint [packages...]').description('lint provided packages. When run without any arguments, lints the whole repository').option('--regex [regexes...]', 'Only lint packages matching the provided regexes').option('--ancestors', 'Additionally lint workspaces that depend on workspaces that have changed', false).option('--descendants', 'Additionally lint workspaces that directly or indirectly depend on the specified packages', false).option('--changed', 'Additionally lint workspaces that have changed compared to the branch specified in --compareBranch').option('--compareBranch <branch>', "Specifies the branch to use with the --changed flag. If not specified, Modular will use the repo's default branch").option('--fix', `Fix the lint errors wherever possible, restages changes if run with ${lintStagedFlag}`).option('--verbose', 'Enables verbose logging within modular.').option('--diff', 'Only lint files that have changed compared to the compare branch').addOption(new _commander.Option(lintStagedFlag, 'Only lint files that have been staged to be committed').conflicts('all')).description('Lints the codebase').action(async (packages, options) => {
  const {
    default: lint
  } = await Promise.resolve().then(() => _interopRequireWildcard(require('./lint')));
  await lint(options, packages);
});
program.command('typecheck [packages...]').description('Typecheck provided packages. If run without any additional arguments, typechecks the entire project').option('--verbose', 'Enables verbose logging within modular.').option('--ancestors', 'Additionally run typecheck for workspaces that depend on workspaces that have changed', false).option('--descendants', 'Additionally run typecheck for workspaces that directly or indirectly depend on the specified packages (can be combined with --changed)', false).option('--changed', 'Run typecheck only for workspaces that have changed compared to the branch specified in --compareBranch').option('--compareBranch <branch>', "Specifies the branch to use with the --changed flag. If not specified, Modular will use the repo's default branch").action(async (packages, options) => {
  (0, _options.validateCompareOptions)(options.compareBranch, options.changed);
  const {
    default: typecheck
  } = await Promise.resolve().then(() => _interopRequireWildcard(require('./typecheck')));
  await typecheck(options, packages);
});
program.command('serve <target>').description('Serves a pre-built modular app').option('--port <value>', 'Port to serve on', '3000').action(async (packageName, options) => {
  const {
    default: serve
  } = await Promise.resolve().then(() => _interopRequireWildcard(require('./serve')));
  await serve(packageName, parseInt(options.port, 10));
});
program.command('select [packages...]').description('Returns an array of selected package names by filtering all workspaces by the packages and options provided').option('--verbose', 'Show verbose information').option('--buildable', 'Select packages and output them in build order as 1-level nested arrays. Default is false', false).option('--changed', 'Select only packages that contain files that have changed compared to the branch specified in --compareBranch. Default is false', false).option('--descendants', 'Additionally select packages that the specified packages directly or indirectly depend on. Default is false', false).option('--ancestors', 'Additionally select packages that directly or indirectly depend on the specified packages. Default is false', false).option('--compareBranch <branch>', "Specifies the branch to use with the --changed flag. If not specified, Modular will use the repo's default branch").action(async (selectedPackages, options) => {
  const {
    default: select
  } = await Promise.resolve().then(() => _interopRequireWildcard(require('./select')));
  (0, _options.validateCompareOptions)(options.compareBranch, options.changed);
  await select({
    ...options,
    selectedPackages
  });
});
//# sourceMappingURL=program.js.map