"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = void 0;
var _prompts = _interopRequireDefault(require("prompts"));
var _actionPreflightCheck = _interopRequireDefault(require("./utils/actionPreflightCheck"));
var _packageTypes = require("./utils/packageTypes");
var _getLocation = _interopRequireDefault(require("./utils/getLocation"));
var _stageView = _interopRequireDefault(require("./utils/stageView"));
var _getWorkspaceInfo = _interopRequireDefault(require("./utils/getWorkspaceInfo"));
var _setupEnv = require("./utils/setupEnv");
var _checkBrowsers = require("./utils/checkBrowsers");
var _checkRequiredFiles = _interopRequireDefault(require("./utils/checkRequiredFiles"));
var logger = _interopRequireWildcard(require("./utils/logger"));
var _createEsbuildBrowserslistTarget = _interopRequireDefault(require("./build-scripts/common-scripts/createEsbuildBrowserslistTarget"));
var _getDependencyInfo = require("./utils/getDependencyInfo");
var _isReactNewApi = require("./utils/isReactNewApi");
var _config = require("./utils/config");
var _determineTargetPaths = _interopRequireDefault(require("./build-scripts/common-scripts/determineTargetPaths"));
var _startWebpack = _interopRequireDefault(require("./build-scripts/webpack-scripts/startWebpack"));
var _start = _interopRequireDefault(require("./build-scripts/esbuild-scripts/start"));
function _getRequireWildcardCache(nodeInterop) { if (typeof WeakMap !== "function") return null; var cacheBabelInterop = new WeakMap(); var cacheNodeInterop = new WeakMap(); return (_getRequireWildcardCache = function (nodeInterop) { return nodeInterop ? cacheNodeInterop : cacheBabelInterop; })(nodeInterop); }
function _interopRequireWildcard(obj, nodeInterop) { if (!nodeInterop && obj && obj.__esModule) { return obj; } if (obj === null || typeof obj !== "object" && typeof obj !== "function") { return { default: obj }; } var cache = _getRequireWildcardCache(nodeInterop); if (cache && cache.has(obj)) { return cache.get(obj); } var newObj = {}; var hasPropertyDescriptor = Object.defineProperty && Object.getOwnPropertyDescriptor; for (var key in obj) { if (key !== "default" && Object.prototype.hasOwnProperty.call(obj, key)) { var desc = hasPropertyDescriptor ? Object.getOwnPropertyDescriptor(obj, key) : null; if (desc && (desc.get || desc.set)) { Object.defineProperty(newObj, key, desc); } else { newObj[key] = obj[key]; } } } newObj.default = obj; if (cache) { cache.set(obj, newObj); } return newObj; }
function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }
async function start(packageName) {
  let target = packageName;
  const workspaceInfo = await (0, _getWorkspaceInfo.default)();
  if (!target) {
    const availablePackages = Object.keys(workspaceInfo);
    const chosenTarget = await (0, _prompts.default)({
      type: 'select',
      name: 'value',
      message: 'Select a package to start',
      choices: availablePackages.map(packageName => ({
        title: packageName,
        value: packageName
      })),
      initial: 0
    });
    target = chosenTarget.value;
  }
  let targetPath = await (0, _getLocation.default)(target);
  await (0, _setupEnv.setupEnvForDirectory)(targetPath);
  const modularType = (0, _packageTypes.getModularType)(targetPath);
  if (!modularType || !(0, _packageTypes.isStartableModularType)(modularType)) {
    throw new Error(`The package at ${targetPath} can't be started because ${modularType ? `has Modular type "${modularType}"` : `has no Modular type`}.`);
  }
  const isEsmView = (0, _packageTypes.isModularType)(targetPath, 'esm-view');
  const isView = (0, _packageTypes.isModularType)(targetPath, 'view');
  if (isView) targetPath = (0, _stageView.default)(target);
  const paths = (0, _determineTargetPaths.default)(target, targetPath);
  // in the case we're an app then we need to make sure that users have no incorrectly
  // setup their app folder.
  isEsmView ? await (0, _checkRequiredFiles.default)([paths.appIndexJs]) : await (0, _checkRequiredFiles.default)([paths.appHtml, paths.appIndexJs]);
  await (0, _checkBrowsers.checkBrowsers)(targetPath);

  // Retrieve dependency info for target to inform the build process
  const {
    importInfo,
    styleImports,
    bundledDependencies,
    bundledResolutions,
    externalDependencies,
    externalResolutions
  } = await (0, _getDependencyInfo.getDependencyInfo)(target);
  logger.debug(`These are the external dependencies and their resolutions: ${JSON.stringify({
    externalDependencies,
    externalResolutions
  })}`);
  logger.debug(`These are the bundled dependencies and their resolutions: ${JSON.stringify({
    bundledDependencies,
    bundledResolutions
  })}`);
  const useReactCreateRoot = (0, _isReactNewApi.isReactNewApi)(externalResolutions);

  // If you want to use webpack then we'll always use webpack. But if you've indicated
  // you want esbuild - then we'll switch you to the new fancy world.
  if ((0, _config.getConfig)('useModularEsbuild', targetPath)) {
    await (0, _start.default)({
      target,
      isApp: !isEsmView,
      importInfo,
      useReactCreateRoot,
      styleImports
    });
  } else {
    const browserTarget = (0, _createEsbuildBrowserslistTarget.default)(targetPath);

    // If it's an app, set it at ESBUILD_TARGET_FACTORY or default to es2015
    // If it's not an app it's an ESM view, then we need es2020
    const esbuildTargetFactory = !isEsmView ? browserTarget : ['es2020'];
    logger.debug(`Using target: ${browserTarget.join(', ')}`);
    (0, _startWebpack.default)(target, esbuildTargetFactory, !isEsmView, importInfo, useReactCreateRoot, styleImports, paths);
  }
}
var _default = (0, _actionPreflightCheck.default)(start);
exports.default = _default;
//# sourceMappingURL=start.js.map