"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.createJestConfig = createJestConfig;
var _path = _interopRequireDefault(require("path"));
var fs = _interopRequireWildcard(require("fs-extra"));
var _globby = _interopRequireDefault(require("globby"));
var _chalk = _interopRequireDefault(require("chalk"));
var _isCi = _interopRequireDefault(require("is-ci"));
var _jestConfig = require("jest-config");
var _getModularRoot = _interopRequireDefault(require("../utils/getModularRoot"));
function _getRequireWildcardCache(nodeInterop) { if (typeof WeakMap !== "function") return null; var cacheBabelInterop = new WeakMap(); var cacheNodeInterop = new WeakMap(); return (_getRequireWildcardCache = function (nodeInterop) { return nodeInterop ? cacheNodeInterop : cacheBabelInterop; })(nodeInterop); }
function _interopRequireWildcard(obj, nodeInterop) { if (!nodeInterop && obj && obj.__esModule) { return obj; } if (obj === null || typeof obj !== "object" && typeof obj !== "function") { return { default: obj }; } var cache = _getRequireWildcardCache(nodeInterop); if (cache && cache.has(obj)) { return cache.get(obj); } var newObj = {}; var hasPropertyDescriptor = Object.defineProperty && Object.getOwnPropertyDescriptor; for (var key in obj) { if (key !== "default" && Object.prototype.hasOwnProperty.call(obj, key)) { var desc = hasPropertyDescriptor ? Object.getOwnPropertyDescriptor(obj, key) : null; if (desc && (desc.get || desc.set)) { Object.defineProperty(newObj, key, desc); } else { newObj[key] = obj[key]; } } } newObj.default = obj; if (cache) { cache.set(obj, newObj); } return newObj; }
function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }
// This list may change as we learn of options where flexibility would be valuable.
// Based on react-scripts supported override options
const supportedOverrides = ['collectCoverageFrom', 'coveragePathIgnorePatterns', 'coverageThreshold', 'moduleNameMapper', 'modulePathIgnorePatterns', 'testPathIgnorePatterns', 'testRunner', 'transformIgnorePatterns', 'coverageProvider'];
const modularSetUpFilesMap = {
  setupFiles: 'setupEnvironment',
  setupFilesAfterEnv: 'setupTests'
};
function createJestConfig(cliOptions, swc) {
  const modularRoot = (0, _getModularRoot.default)();
  const absolutePackagesPath = _path.default.resolve(modularRoot, 'packages');
  const absoluteModularGlobalConfigsPath = _path.default.resolve(modularRoot, 'modular');
  const jestConfig = {
    ..._jestConfig.defaults,
    ...cliOptions,
    displayName: 'test',
    resetMocks: false,
    transform: swc ? {
      '^.+\\.(js|jsx|mjs|cjs)$': require.resolve('@swc/jest'),
      '^.+\\.(ts|tsx)$': [require.resolve('@swc/jest'),
      // Pass a swc configuration that closely matches our ts-config
      {
        $schema: 'https://json.schemastore.org/swcrc',
        sourceMaps: true,
        module: {
          type: 'commonjs',
          strictMode: true,
          noInterop: false
        },
        jsc: {
          externalHelpers: false,
          target: 'es2017',
          parser: {
            syntax: 'typescript',
            tsx: true,
            decorators: false,
            dynamicImport: true
          },
          transform: {
            legacyDecorator: true,
            decoratorMetadata: false,
            react: {
              throwIfNamespace: false,
              useBuiltins: false,
              pragma: 'React.createElement',
              pragmaFrag: 'React.Fragment'
            }
          },
          keepClassNames: true
        }
      }],
      '^.+\\.(css|scss)$': require.resolve('jest-transform-stub'),
      '.+\\.(jpg|jpeg|png|gif|eot|otf|webp|svg|ttf|woff|woff2|mp4|webm|wav|mp3|m4a|aac|oga)$': require.resolve('jest-transform-stub')
    } : {
      // If SWC flag isn't passed, use ts-jest and babel instead, for ts and js respectively
      // don't typecheck tests in CI
      '^.+\\.(ts|tsx)$': _isCi.default ? [require.resolve('ts-jest'), {
        diagnostics: false,
        isolatedModules: true
      }] : require.resolve('ts-jest'),
      '^.+\\.(js|jsx|mjs|cjs)$': [require.resolve('babel-jest'), {
        presets: [require.resolve('babel-preset-react-app')]
      }],
      '^.+\\.(css|scss)$': require.resolve('jest-transform-stub'),
      '.+\\.(jpg|jpeg|png|gif|eot|otf|webp|svg|ttf|woff|woff2|mp4|webm|wav|mp3|m4a|aac|oga)$': require.resolve('jest-transform-stub')
    },
    transformIgnorePatterns: ['[/\\\\]node_modules[/\\\\].+\\.(js|jsx|mjs|cjs|ts|tsx)$', '^.+\\.module\\.(css|sass|scss)$'],
    moduleNameMapper: {
      '^.+\\.(css|styl|less|sass|scss|png|jpg|ttf|woff|woff2)$': require.resolve('jest-transform-stub'),
      '^react-native$': require.resolve('react-native-web')
    },
    watchPlugins: [require.resolve('jest-watch-typeahead/filename'), require.resolve('jest-watch-typeahead/testname')],
    moduleFileExtensions: ['web.js', 'js', 'web.ts', 'ts', 'web.tsx', 'tsx', 'json', 'web.jsx', 'jsx', 'node'],
    testRunner: require.resolve('jest-circus/runner'),
    testPathIgnorePatterns: ['/node_modules/', '/dist/'],
    rootDir: absolutePackagesPath,
    roots: ['<rootDir>'],
    testMatch: ['<rootDir>/**/src/**/*.{spec,test}.{js,jsx,ts,tsx}'],
    coverageDirectory: _path.default.resolve(modularRoot, 'coverage'),
    collectCoverageFrom: ['<rootDir>/**/src/**/*.{js,jsx,ts,tsx}', '!**/*.d.ts'],
    coveragePathIgnorePatterns: ['/__tests__/', '/node_modules/', 'serviceWorker.ts'],
    setupFiles: _jestConfig.defaults.setupFiles.concat(_globby.default.sync(`setupEnvironment.{js,jsx,ts,tsx}`, {
      cwd: absoluteModularGlobalConfigsPath
    }).map(f => _path.default.join(absoluteModularGlobalConfigsPath, f))),
    setupFilesAfterEnv: _globby.default.sync(`setupTests.{js,jsx,ts,tsx}`, {
      cwd: absoluteModularGlobalConfigsPath
    }).map(f => _path.default.join(absoluteModularGlobalConfigsPath, f))
  };
  const rootPackageJson = fs.readJSONSync(_path.default.join(modularRoot, 'package.json'));
  const packageJsonJest = rootPackageJson === null || rootPackageJson === void 0 ? void 0 : rootPackageJson.jest;
  const jestConfigFile = fs.existsSync(_path.default.join(modularRoot, 'jest.config.js'));
  if (jestConfigFile) {
    throw new Error(_chalk.default.red('\nWe detected a jest.config.js file in your root directory.\n' + 'We read your jest options from package.json.\n', `
        {
          "jest": {}
        }
        `));
  }
  if (packageJsonJest) {
    const overrideKeys = Object.keys(packageJsonJest);
    const unsupportedOverrides = overrideKeys.filter(key => !supportedOverrides.includes(key));
    const setUpOptions = unsupportedOverrides.filter(key => key === 'setupFiles' || key === 'setupFilesAfterEnv');
    if (setUpOptions.length) {
      throw new Error(_chalk.default.red('\n We detected options in your Jest configuration' + ' that should be initialized in here: \n\n' + setUpOptions.map(key => _chalk.default.bold('  \u2022 ' + key + `: modular/${modularSetUpFilesMap[key]}.{js,ts}`)).join('\n'), '\n\n We will load theses files for you. \n'));
    }
    if (unsupportedOverrides.length) {
      throw new Error(_chalk.default.red('\nModular only supports overriding these Jest options:\n\n' + supportedOverrides.map(key => _chalk.default.bold('  \u2022 ' + key)).join('\n') + '\n\n' + 'These options are not supported by Modular:\n\n' + unsupportedOverrides.map(key => _chalk.default.bold('  \u2022 ' + key)).join('\n'), '\n'));
    }
    const mergedMapper = {
      ...jestConfig.moduleNameMapper,
      ...packageJsonJest.moduleNameMapper
    };
    Object.assign(jestConfig, {
      ...packageJsonJest,
      moduleNameMapper: mergedMapper
    });
  }
  return jestConfig;
}
//# sourceMappingURL=config.js.map