"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = void 0;
var path = _interopRequireWildcard(require("path"));
var _resolve = _interopRequireDefault(require("resolve"));
var _actionPreflightCheck = _interopRequireDefault(require("../utils/actionPreflightCheck"));
var _execAsync = _interopRequireDefault(require("../utils/execAsync"));
var _getModularRoot = _interopRequireDefault(require("../utils/getModularRoot"));
var _getAllWorkspaces = require("../utils/getAllWorkspaces");
var _resolveAsBin = require("../utils/resolveAsBin");
var logger = _interopRequireWildcard(require("../utils/logger"));
var _utils = require("./utils");
var _selectWorkspaces = require("../utils/selectWorkspaces");
var _unobtrusiveModular = require("../utils/unobtrusiveModular");
var _config = require("../utils/config");
function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }
function _getRequireWildcardCache(nodeInterop) { if (typeof WeakMap !== "function") return null; var cacheBabelInterop = new WeakMap(); var cacheNodeInterop = new WeakMap(); return (_getRequireWildcardCache = function (nodeInterop) { return nodeInterop ? cacheNodeInterop : cacheBabelInterop; })(nodeInterop); }
function _interopRequireWildcard(obj, nodeInterop) { if (!nodeInterop && obj && obj.__esModule) { return obj; } if (obj === null || typeof obj !== "object" && typeof obj !== "function") { return { default: obj }; } var cache = _getRequireWildcardCache(nodeInterop); if (cache && cache.has(obj)) { return cache.get(obj); } var newObj = {}; var hasPropertyDescriptor = Object.defineProperty && Object.getOwnPropertyDescriptor; for (var key in obj) { if (key !== "default" && Object.prototype.hasOwnProperty.call(obj, key)) { var desc = hasPropertyDescriptor ? Object.getOwnPropertyDescriptor(obj, key) : null; if (desc && (desc.get || desc.set)) { Object.defineProperty(newObj, key, desc); } else { newObj[key] = obj[key]; } } } newObj.default = obj; if (cache) { cache.set(obj, newObj); } return newObj; }
// via https://github.com/facebook/create-react-app/blob/master/packages/react-scripts/scripts/test.js
// This is a very dirty workaround for https://github.com/facebook/jest/issues/5913.
// We're trying to resolve the environment ourselves because Jest does it incorrectly.
// TODO: remove this as soon as it's fixed in Jest.
function resolveJestDefaultEnvironment(name) {
  const jestDir = path.dirname(_resolve.default.sync('jest', {
    basedir: __dirname
  }));
  const jestCLIDir = path.dirname(_resolve.default.sync('jest-cli', {
    basedir: jestDir
  }));
  const jestConfigDir = path.dirname(_resolve.default.sync('jest-config', {
    basedir: jestCLIDir
  }));
  return _resolve.default.sync(name, {
    basedir: jestConfigDir
  });
}
async function test(options, packages) {
  var _regexes2;
  const {
    bypass,
    swc,
    ancestors,
    descendants,
    changed,
    regex: userRegexes,
    compareBranch,
    debug,
    env,
    reporters,
    testResultsProcessor,
    ...jestOptions
  } = options;

  // create argv from jest Options
  const cleanArgv = [];

  // pass in jest configuration
  const {
    createJestConfig
  } = await Promise.resolve().then(() => _interopRequireWildcard(require('./config')));
  const configuredSwc = swc ? swc : (0, _config.getConfig)('swcJest', (0, _getModularRoot.default)());
  cleanArgv.push('--config', (0, _utils.generateJestConfig)(createJestConfig({
    reporters,
    testResultsProcessor
  }, configuredSwc)));
  let resolvedEnv;
  try {
    resolvedEnv = resolveJestDefaultEnvironment(`jest-environment-${env}`);
  } catch (e) {
    // ignore
  }
  if (!resolvedEnv) {
    try {
      resolvedEnv = resolveJestDefaultEnvironment(env);
    } catch (e) {
      // ignore
    }
  }
  const testEnvironment = resolvedEnv || env;
  cleanArgv.push(`--env=${testEnvironment}`);
  let regexes = [];
  let nonModularTargets;
  let modularTargets;

  // If --bypass, pass on all options to jest
  if (bypass) {
    // Modular flags compatible with --bypass that shouldn't be passed to Jest
    const bypassCompatibleFlags = ['verbose', 'env', 'swc', 'bypass'];
    cleanArgv.push(...Object.entries(options).filter(([key, v]) => {
      return !bypassCompatibleFlags.some(option => key === option);
    }).map(([key, v]) => {
      const booleanValue = /^(true)$/.exec(String(v));
      return `--${key}${!!booleanValue ? '' : `=${String(v)}`}`;
    }));

    // Get the options that have been incorrectly placed in packages[]
    if (packages) {
      cleanArgv.push(...packages);
    }
  } else {
    var _regexes;
    // pass on jest programatic options
    const jestArgv = Object.entries(jestOptions).map(([key, v]) => {
      const booleanValue = /^(true)$/.exec(String(v));
      return `--${key}${!!booleanValue ? '' : `=${String(v)}`}`;
    });
    cleanArgv.push(...jestArgv);
    const additionalOptions = [];
    const cleanRegexes = [];
    const cleanPackages = [];

    // Commander seems to read options (--option) passed to the modular test command as
    // arguments (in this case packages), so we filter them out and pass them to jest
    if (packages) {
      extractOptions(packages, cleanPackages, additionalOptions);
    }
    const [workspaceMap] = await (0, _getAllWorkspaces.getAllWorkspaces)((0, _getModularRoot.default)());
    const isSelective = changed || ancestors || descendants || (userRegexes === null || userRegexes === void 0 ? void 0 : userRegexes.length) || cleanPackages.length;
    let selectedTargets;
    if (!isSelective) {
      // If no package and no selector is specified, all packages are specified
      selectedTargets = [...workspaceMap.keys()];
    } else {
      // Otherwise, calculate which packages are selected
      selectedTargets = await (0, _selectWorkspaces.selectWorkspaces)({
        targets: cleanPackages,
        changed,
        ancestors,
        descendants,
        compareBranch
      });
    }

    // Split packages into modular and non-modular testable. Make sure that "root" is not there.
    [modularTargets, nonModularTargets] = (0, _unobtrusiveModular.partitionPackages)(selectedTargets, workspaceMap, 'test');
    // Compute patterns to pass Jest for the packages that we want to test
    const packageRegexes = await (0, _unobtrusiveModular.computeRegexesFromPackageNames)(modularTargets);

    // Merge and dedupe selective regexes + user-specified regexes
    regexes = [...new Set([...packageRegexes, ...(userRegexes ?? [])])];
    if ((_regexes = regexes) !== null && _regexes !== void 0 && _regexes.length) {
      extractOptions(regexes, cleanRegexes, additionalOptions);
    }
    logger.debug(`Modular package targets for tests are ${JSON.stringify(modularTargets)}.`);
    logger.debug(`Non-modular targets selected and eligible for tests are: ${JSON.stringify(nonModularTargets)}.`);
    logger.debug(`Regexes generated from Modular targets are: ${JSON.stringify(packageRegexes)}.`);
    logger.debug(`User-provided regexes are: ${JSON.stringify(userRegexes)}.`);
    logger.debug(`Final regexes to pass to Jest are: ${JSON.stringify(cleanRegexes)}.`);

    // If we computed no regexes and there are no non-modular packages to test, bail out
    if (!(cleanRegexes !== null && cleanRegexes !== void 0 && cleanRegexes.length) && !nonModularTargets.length) {
      process.stdout.write('No workspaces found in selection\n');
      process.exit(0);
    }

    // Push any additional options passed in by debugger or other processes
    cleanArgv.push(...additionalOptions);

    // Finally add the script regexes to run (at the beginning of the array as to not be mistaken for properties assigned to a flag)
    cleanArgv.unshift(...cleanRegexes);
  }
  const jestBin = await (0, _resolveAsBin.resolveAsBin)('jest-cli');
  let testBin = jestBin,
    testArgs = cleanArgv;
  if (debug) {
    // If we're trying to attach to a debugger, we need to run node
    // instead. This moves around the command line arguments for so.
    testBin = 'node';
    testArgs = ['--inspect-brk', jestBin, ...testArgs.filter(x => x !== '--inspect-brk')];
  }

  // First run Modular tests with Jest. We're not iterating, but providing arguments to Jest, so we do this only if we have Modular test to run
  if ((_regexes2 = regexes) !== null && _regexes2 !== void 0 && _regexes2.length || bypass) {
    logger.debug(`Running ${testBin} with cwd: ${(0, _getModularRoot.default)()} and args: ${JSON.stringify(testArgs)}`);
    try {
      await (0, _execAsync.default)(testBin, testArgs, {
        cwd: (0, _getModularRoot.default)(),
        log: false,
        // @ts-ignore
        env: {
          BABEL_ENV: 'test',
          NODE_ENV: 'test',
          MODULAR_ROOT: (0, _getModularRoot.default)()
        }
      });
    } catch (err) {
      logger.debug(err.message);
      throw new Error('\u2715 Modular test did not pass');
    }
  }
  if (nonModularTargets) {
    // ...Then run non-Modular (if there are any) tests by running the tests script for each package
    for (const target of nonModularTargets) {
      try {
        await (0, _execAsync.default)(`yarn`, ['workspace', target, 'test'], {
          cwd: (0, _getModularRoot.default)(),
          log: false
        });
      } catch (err) {
        logger.debug(err.message);
        throw new Error('\u2715 Modular test did not pass');
      }
    }
  }
}

/**
 * Split out options (--option) that commander incorrectly assumes are arguments
 * @param args list of arguments provided by commander
 * @param cleanedArgs list of arguments after removing options
 * @param additionalOptions list of options extracted from arguments
 */
function extractOptions(args, cleanedArgs, additionalOptions) {
  args.forEach(reg => {
    if (/^(--)([\w]+)/.exec(reg)) {
      return additionalOptions.push(reg);
    }
    return cleanedArgs.push(reg);
  });
  if (additionalOptions.length) {
    additionalOptions.map(reg => {
      const [option, value] = reg.split('=');
      if (value) {
        return `${option}=${JSON.stringify(value)}`;
      }
      return option;
    });
  }
}
var _default = (0, _actionPreflightCheck.default)(test);
exports.default = _default;
//# sourceMappingURL=index.js.map