"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.addFixturePackage = addFixturePackage;
exports.cleanup = cleanup;
exports.createModularTestContext = createModularTestContext;
exports.generateJestConfig = generateJestConfig;
exports.getRealModularRootInTest = getRealModularRootInTest;
exports.mockInstallTemplate = mockInstallTemplate;
exports.runModularForTests = runModularForTests;
exports.runModularForTestsAsync = runModularForTestsAsync;
exports.runModularPipeLogs = runModularPipeLogs;
exports.runYarnModular = runYarnModular;
var _path = _interopRequireDefault(require("path"));
var _util = require("util");
var _fs = require("fs");
var _rimraf2 = _interopRequireDefault(require("rimraf"));
var _execa = _interopRequireDefault(require("execa"));
var _fsExtra = _interopRequireWildcard(require("fs-extra"));
var tmp = _interopRequireWildcard(require("tmp"));
var _findUp = _interopRequireDefault(require("find-up"));
function _getRequireWildcardCache(nodeInterop) { if (typeof WeakMap !== "function") return null; var cacheBabelInterop = new WeakMap(); var cacheNodeInterop = new WeakMap(); return (_getRequireWildcardCache = function (nodeInterop) { return nodeInterop ? cacheNodeInterop : cacheBabelInterop; })(nodeInterop); }
function _interopRequireWildcard(obj, nodeInterop) { if (!nodeInterop && obj && obj.__esModule) { return obj; } if (obj === null || typeof obj !== "object" && typeof obj !== "function") { return { default: obj }; } var cache = _getRequireWildcardCache(nodeInterop); if (cache && cache.has(obj)) { return cache.get(obj); } var newObj = {}; var hasPropertyDescriptor = Object.defineProperty && Object.getOwnPropertyDescriptor; for (var key in obj) { if (key !== "default" && Object.prototype.hasOwnProperty.call(obj, key)) { var desc = hasPropertyDescriptor ? Object.getOwnPropertyDescriptor(obj, key) : null; if (desc && (desc.get || desc.set)) { Object.defineProperty(newObj, key, desc); } else { newObj[key] = obj[key]; } } } newObj.default = obj; if (cache) { cache.set(obj, newObj); } return newObj; }
function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }
const rimraf = (0, _util.promisify)(_rimraf2.default);

/**
 * This is a duplicate copy of `getModularRoot`.
 * It exists as a standalone test util so that we can mock the real `getMockRoot` in tests.
 *
 * A copy of the real implementation (i.e. one that returns the modular root of modular itself) is
 * still needed in test code for things like test setup (and the other utilities in here).
 */
function getRealModularRootInTest() {
  function isModularRoot(packageJsonPath) {
    var _packageJson$modular;
    const packageJson = _fsExtra.default.readJSONSync(packageJsonPath, {
      encoding: 'utf8'
    });
    return (packageJson === null || packageJson === void 0 ? void 0 : (_packageJson$modular = packageJson.modular) === null || _packageJson$modular === void 0 ? void 0 : _packageJson$modular.type) === 'root';
  }
  function findModularRoot() {
    try {
      const modularRoot = _findUp.default.sync(directory => {
        const packageJsonPath = _path.default.join(directory, 'package.json');
        if (_findUp.default.sync.exists(packageJsonPath) && isModularRoot(packageJsonPath)) {
          return packageJsonPath;
        }
        return;
      }, {
        type: 'file',
        allowSymlinks: false
      });
      return modularRoot ? _path.default.normalize(_path.default.dirname(modularRoot)) : undefined;
    } catch (err) {
      throw new Error(err);
    }
  }
  const modularRoot = findModularRoot();
  if (modularRoot === undefined) {
    throw new Error('Could not find modular root.');
  }
  return modularRoot;
}
const modularRoot = getRealModularRootInTest();
async function cleanup(packageNames) {
  const packagesPath = _path.default.join(modularRoot, 'packages');
  const distPath = _path.default.join(modularRoot, 'dist');
  for (const packageName of packageNames) {
    await rimraf(_path.default.join(packagesPath, packageName));
    await rimraf(_path.default.join(distPath, packageName));
  }

  // run yarn so yarn.lock gets reset
  await (0, _execa.default)('yarnpkg', ['--silent'], {
    cwd: modularRoot
  });
}
async function addFixturePackage(name, options = {
  copy: true
}) {
  const packageSrcDir = _path.default.join(modularRoot, 'packages', name, 'src');
  await runYarnModular(modularRoot, `add ${name} --unstable-type package`, {
    stdio: 'inherit'
  });
  await _fsExtra.default.emptyDir(packageSrcDir);
  if (options.copy) {
    await _fsExtra.default.copy(_path.default.join(__dirname, '..', '__tests__', '__fixtures__', 'packages', name), packageSrcDir);
  }
}

/**
 * Creates a temporary Modular repo test environment with a default package.json and an empty packages workspace.
 * Modular node_modules is symlinked in the parent directory to provide all required dependencies without installing them.
 *
 * Use to create a clean context to run tests in where you can call `yarn modular` commands
 * without having to install dependencies nor tests within the main Modular repo.
 * @returns Path to temporary directory
 */
function createModularTestContext() {
  // Modular node_modules are copied in the parent folder
  const tempDir = tmp.dirSync({
    unsafeCleanup: true
  }).name;
  _fsExtra.default.symlinkSync(_path.default.join(modularRoot, 'node_modules'), _path.default.join(tempDir, 'node_modules'));

  // Actual mock modular repo is nested in the temp directory so that it can have its own clean node_modules
  const tempModularRepo = _path.default.join(tempDir, 'temp_repo');
  (0, _fs.mkdirSync)(tempModularRepo);

  // Create mock modular package.json
  const packageJson = {
    name: 'temp',
    license: 'MIT',
    private: true,
    modular: {
      type: 'root'
    },
    workspaces: ['packages/**', 'templates/**'],
    scripts: {
      modular: `ts-node ${modularRoot}/packages/modular-scripts/src/cli.ts`
    },
    browserslist: {
      production: ['>0.2%', 'not dead', 'not op_mini all'],
      development: ['last 1 chrome version', 'last 1 firefox version', 'last 1 safari version']
    },
    dependencies: {
      react: '^18.2.0',
      'react-dom': '^18.2.0'
    }
  };
  _fsExtra.default.writeJSONSync(_path.default.join(tempModularRepo, 'package.json'), packageJson, {
    spaces: 2
  });
  _fsExtra.default.writeJSONSync(_path.default.join(tempModularRepo, 'tsconfig.json'), {
    extends: 'modular-scripts/tsconfig.json',
    include: ['modular', 'packages/**/src']
  });
  _fsExtra.default.copySync(_path.default.join(modularRoot, 'modular'), _path.default.join(tempModularRepo, 'modular'));
  return tempModularRepo;
}

/**
 * Mocks the installation of a template in the provided modular repo to avoid running `yarn` or installing it from a registry.
 *
 * Copies the template into a Templates workspace and symlinks them in node_modules so that it can be picked up by modular add.
 * @param templatePath Path to directory containing templates
 * @param modularRepo Modular repo in which to install them
 */
function mockInstallTemplate(templatePath, modularRepo) {
  const tempTemplatesPath = _path.default.join(modularRepo, 'templates');
  const templateName = _path.default.basename(templatePath);

  // Copy the template into the temporary repo
  _fsExtra.default.copySync(templatePath, _path.default.join(tempTemplatesPath, templateName));

  // Symlink the templates into node_modules
  const tempRepoNodeModules = _path.default.join(modularRepo, 'node_modules');
  if (!_fsExtra.default.existsSync(tempRepoNodeModules)) _fsExtra.default.mkdirSync(tempRepoNodeModules);
  _fsExtra.default.symlinkSync(_path.default.join(tempTemplatesPath, templateName), _path.default.join(tempRepoNodeModules, templateName));
}

/**
 * Generates the Jest --config flag contents to pass when calling Jest based on config JSON provided
 *
 * - On Mac, it will provide a stringyfied version of the config JSON provided
 *
 * - On Windows, it will write the config JSON to a file in a temp directory and provde the path to pass
 */
function generateJestConfig(jestConfig) {
  if (process.platform === 'win32') {
    const tempConfigPath = _path.default.join(tmp.dirSync().name, 'temp-jest-config.json');
    (0, _fsExtra.writeJSONSync)(tempConfigPath, jestConfig);
    return `${tempConfigPath}`;
  } else {
    return `${JSON.stringify(jestConfig)}`;
  }
}

/**
 * Run the main repo's modular cli with the specified arguments, skipping modular checks by default to improve performance
 * Should be used by most tests - logs from the process are inherited by default
 *
 * @param cwd Where to run modular
 * @param args String of arguments to pass to modular
 * @param opts Options to pass to execa
 * @param stdio Override 'inherit' defailt stdio option
 * @param skipChecks Override 'true' default to skipping startup and preflight checks
 */
function runModularForTests(cwd, args, opts = {}, stdio = 'inherit', skipChecks = 'true') {
  return _execa.default.sync(_path.default.join(modularRoot, '/node_modules/.bin/ts-node'), [_path.default.join(modularRoot, '/packages/modular-scripts/src/cli.ts'), ...args.split(/ +(?=(?:(?:[^"]*"){2})*[^"]*$)/g)], {
    cwd,
    env: {
      ...process.env,
      SKIP_MODULAR_STARTUP_CHECK: skipChecks,
      SKIP_PREFLIGHT_CHECK: skipChecks,
      CI: 'true'
    },
    stdio,
    cleanup: true,
    all: true,
    ...opts
  });
}

/**
 * Wrapper of runModularForTests that runs checks to make it safe & pipes output
 * Skip checks is false by default when we pipe output as unsafe output includes warnings that Modular repository might be invalid
 */
function runModularPipeLogs(cwd, args, skipChecks = 'false', opts = {}) {
  return runModularForTests(cwd, args, opts, 'pipe', skipChecks);
}

/**
 * Async alternative to runModularForTests
 */
async function runModularForTestsAsync(cwd, args, opts = {}, stdio = 'inherit', skipChecks = 'true') {
  return (0, _execa.default)(_path.default.join(modularRoot, '/node_modules/.bin/ts-node'), [_path.default.join(modularRoot, '/packages/modular-scripts/src/cli.ts'), ...args.split(/ +(?=(?:(?:[^"]*"){2})*[^"]*$)/g)], {
    cwd,
    env: {
      ...process.env,
      SKIP_MODULAR_STARTUP_CHECK: skipChecks,
      SKIP_PREFLIGHT_CHECK: skipChecks,
      CI: 'true'
    },
    stdio,
    all: true,
    cleanup: true,
    ...opts
  });
}

/**
 * Runs `yarnpkg modular` in given directory with minimal configuration
 */
async function runYarnModular(cwd, args, opts = {}) {
  return (0, _execa.default)('yarnpkg', ['modular', ...args.split(/ +(?=(?:(?:[^"]*"){2})*[^"]*$)/g)], {
    cwd,
    all: true,
    cleanup: true,
    ...opts
  });
}
//# sourceMappingURL=utils.js.map