"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = void 0;
var _isCi = _interopRequireDefault(require("is-ci"));
var _typescript = _interopRequireDefault(require("typescript"));
var _chalk = _interopRequireDefault(require("chalk"));
var _getPackageMetadata = _interopRequireDefault(require("./utils/getPackageMetadata"));
var logger = _interopRequireWildcard(require("./utils/logger"));
var _getModularRoot = _interopRequireDefault(require("./utils/getModularRoot"));
var _actionPreflightCheck = _interopRequireDefault(require("./utils/actionPreflightCheck"));
var _getAllWorkspaces = require("./utils/getAllWorkspaces");
var _selectWorkspaces = require("./utils/selectWorkspaces");
var _unobtrusiveModular = require("./utils/unobtrusiveModular");
var _execAsync = _interopRequireDefault(require("./utils/execAsync"));
function _getRequireWildcardCache(nodeInterop) { if (typeof WeakMap !== "function") return null; var cacheBabelInterop = new WeakMap(); var cacheNodeInterop = new WeakMap(); return (_getRequireWildcardCache = function (nodeInterop) { return nodeInterop ? cacheNodeInterop : cacheBabelInterop; })(nodeInterop); }
function _interopRequireWildcard(obj, nodeInterop) { if (!nodeInterop && obj && obj.__esModule) { return obj; } if (obj === null || typeof obj !== "object" && typeof obj !== "function") { return { default: obj }; } var cache = _getRequireWildcardCache(nodeInterop); if (cache && cache.has(obj)) { return cache.get(obj); } var newObj = {}; var hasPropertyDescriptor = Object.defineProperty && Object.getOwnPropertyDescriptor; for (var key in obj) { if (key !== "default" && Object.prototype.hasOwnProperty.call(obj, key)) { var desc = hasPropertyDescriptor ? Object.getOwnPropertyDescriptor(obj, key) : null; if (desc && (desc.get || desc.set)) { Object.defineProperty(newObj, key, desc); } else { newObj[key] = obj[key]; } } } newObj.default = obj; if (cache) { cache.set(obj, newObj); } return newObj; }
function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }
const COMPILER_OPTIONS_ALLOW_LIST = ['jsx', 'strict'];
const DEFAULT_COMPILER_OPTIONS = {
  noEmit: true
};
const DEFAULT_EXCLUDES = ['node_modules', 'bower_components', 'jspm_packages', 'tmp', '**/dist-types', '**/dist-cjs', '**/dist-es', 'dist', '**/__fixtures__'];
function restrictUserTsconfig(userTsConfig, replaceInclude) {
  const {
    compilerOptions,
    ...rest
  } = userTsConfig;

  // The exclude list here is different to that in getPackageInfo() because we want
  // to test more files during a typecheck compared to a build (test/spec files). During a build,
  // there might be various files that we don't want to end up in the output.
  const tsConfig = {
    ...rest,
    exclude: [...DEFAULT_EXCLUDES]
  };
  const combinedCompilerOptions = {
    ...DEFAULT_COMPILER_OPTIONS
  };

  // Where the user has defined allowlist-supported compiler options, apply them
  for (const item of COMPILER_OPTIONS_ALLOW_LIST) {
    if ((compilerOptions === null || compilerOptions === void 0 ? void 0 : compilerOptions[item]) !== undefined) {
      // eslint-disable-next-line @typescript-eslint/no-unsafe-assignment
      combinedCompilerOptions[item] = compilerOptions[item];
    }
  }
  tsConfig.compilerOptions = combinedCompilerOptions;

  // If the user provided selective options, use a computed `include` config instead of what is derived from tsconfig.json
  if (replaceInclude) {
    tsConfig.include = replaceInclude;
  }
  return tsConfig;
}
async function typecheck(options, packages) {
  const {
    ancestors,
    descendants,
    changed,
    compareBranch
  } = options;
  const isSelective = changed || ancestors || descendants || packages.length;
  const modularRoot = (0, _getModularRoot.default)();
  const [workspaceMap] = await (0, _getAllWorkspaces.getAllWorkspaces)();
  let selectedTargets;
  if (isSelective) {
    selectedTargets = await (0, _selectWorkspaces.selectWorkspaces)({
      targets: packages,
      changed,
      compareBranch,
      descendants,
      ancestors
    });
  } else {
    selectedTargets = [...workspaceMap.keys()];
  }

  // Split packages into modular and non-modular testable. Make sure that "root" is not there.
  const [modularTargets, nonModularTargets] = (0, _unobtrusiveModular.partitionPackages)(selectedTargets, workspaceMap, 'typecheck');
  const targetLocations = ['modular'];
  for (const [pkgName, pkg] of workspaceMap) {
    if (modularTargets.includes(pkgName)) {
      targetLocations.push(pkg.location);
    }
  }
  logger.debug(`Typechecking the following locations: ${JSON.stringify(targetLocations)}`);
  const {
    typescriptConfig
  } = await (0, _getPackageMetadata.default)();
  const tsConfig = restrictUserTsconfig(typescriptConfig, targetLocations);
  if (modularTargets.length) {
    const diagnosticHost = {
      getCurrentDirectory: () => (0, _getModularRoot.default)(),
      getNewLine: () => _typescript.default.sys.newLine,
      getCanonicalFileName: file => _typescript.default.sys.useCaseSensitiveFileNames ? file : toFileNameLowerCase(file)
    };

    // Parse all config except for compilerOptions
    const configParseResult = _typescript.default.parseJsonConfigFileContent(tsConfig, _typescript.default.sys, modularRoot);
    if (configParseResult.errors.length > 0) {
      logger.error('Failed to parse your tsconfig.json');
      throw new Error(_typescript.default.formatDiagnostics(configParseResult.errors, diagnosticHost));
    }
    const program = _typescript.default.createProgram(configParseResult.fileNames, configParseResult.options);

    // Pulled from typescript's getCanonicalFileName logic
    // eslint-disable-next-line  no-useless-escape
    const fileNameLowerCaseRegExp = /[^\u0130\u0131\u00DFa-z0-9\\/:\-_\. ]+/g;
    function toFileNameLowerCase(x) {
      return fileNameLowerCaseRegExp.test(x) ? x.replace(fileNameLowerCaseRegExp, x.toLowerCase()) : x;
    }
    program.getSourceFiles().map(f => f.fileName).sort().forEach(f => {
      logger.debug(f);
    });

    // Does not emit files or typings but will add declaration diagnostics to our errors
    // This will ensure that makeTypings will be successful in CI before actually attempting to build
    const emitResult = program.emit();
    const diagnostics = _typescript.default.getPreEmitDiagnostics(program).concat(emitResult.diagnostics);
    if (diagnostics.length) {
      if (_isCi.default) {
        // formatDiagnostics will return a readable list of error messages, each with its own line
        throw new Error(_typescript.default.formatDiagnostics(diagnostics, diagnosticHost));
      }

      // formatDiagnosticsWithColorAndContext will return a list of errors, each with its own line
      // and provide an expanded snapshot of the line with the error
      throw new Error(_typescript.default.formatDiagnosticsWithColorAndContext(diagnostics, diagnosticHost));
    }
  }
  if (nonModularTargets.length) {
    logger.debug(`Running typecheck command in the following non-modular packages: ${JSON.stringify(nonModularTargets)}`);
    for (const target of nonModularTargets) {
      await (0, _execAsync.default)(`yarn`, ['workspace', target, 'typecheck'], {
        cwd: (0, _getModularRoot.default)(),
        log: false
      });
    }
  }

  // "✓ Typecheck passed"
  logger.log(_chalk.default.green('\u2713 Typecheck passed'));
}
var _default = (0, _actionPreflightCheck.default)(typecheck);
exports.default = _default;
//# sourceMappingURL=typecheck.js.map