"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.filterDependencies = filterDependencies;
exports.partitionDependencies = partitionDependencies;
var _micromatch = _interopRequireDefault(require("micromatch"));
var semver = _interopRequireWildcard(require("semver"));
var logger = _interopRequireWildcard(require("./logger"));
var _config = require("./config");
function _getRequireWildcardCache(nodeInterop) { if (typeof WeakMap !== "function") return null; var cacheBabelInterop = new WeakMap(); var cacheNodeInterop = new WeakMap(); return (_getRequireWildcardCache = function (nodeInterop) { return nodeInterop ? cacheNodeInterop : cacheBabelInterop; })(nodeInterop); }
function _interopRequireWildcard(obj, nodeInterop) { if (!nodeInterop && obj && obj.__esModule) { return obj; } if (obj === null || typeof obj !== "object" && typeof obj !== "function") { return { default: obj }; } var cache = _getRequireWildcardCache(nodeInterop); if (cache && cache.has(obj)) { return cache.get(obj); } var newObj = {}; var hasPropertyDescriptor = Object.defineProperty && Object.getOwnPropertyDescriptor; for (var key in obj) { if (key !== "default" && Object.prototype.hasOwnProperty.call(obj, key)) { var desc = hasPropertyDescriptor ? Object.getOwnPropertyDescriptor(obj, key) : null; if (desc && (desc.get || desc.set)) { Object.defineProperty(newObj, key, desc); } else { newObj[key] = obj[key]; } } } newObj.default = obj; if (cache) { cache.set(obj, newObj); } return newObj; }
function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }
// Filter out dependencies that are in blocklist
function filterDependencies(workspacePath, {
  dependencies,
  workspaceInfo
}) {
  const externalBlockList = (0, _config.getConfig)('externalBlockList', workspacePath);
  const externalAllowList = (0, _config.getConfig)('externalAllowList', workspacePath);
  return partitionDependencies({
    dependencies,
    allowList: externalAllowList,
    blockList: externalBlockList,
    workspaceInfo
  });
}
function partitionDependencies({
  dependencies,
  workspaceInfo,
  // By default, everything is externalized
  allowList: externalizeList = ['**'],
  // By default, nothing is bundled
  blockList: bundleList = []
}) {
  logger.debug('Filtering dependencies...');
  logger.debug(`External block list for dependencies is: ${JSON.stringify(externalizeList)}`);
  logger.debug(`External allow list for dependencies is: ${JSON.stringify(bundleList)}`);
  return Object.entries(dependencies).reduce((acc, [name, version]) => {
    var _workspaceInfo$name;
    const isBlocked = _micromatch.default.isMatch(name, bundleList);
    const isAllowed = _micromatch.default.isMatch(name, externalizeList);
    const workspaceVersion = (workspaceInfo === null || workspaceInfo === void 0 ? void 0 : (_workspaceInfo$name = workspaceInfo[name]) === null || _workspaceInfo$name === void 0 ? void 0 : _workspaceInfo$name.version) ?? '';
    const hasWorkspacePrefix = version.startsWith('workspace:');
    const packageVersion = hasWorkspacePrefix ? version.split('workspace:')[1] : version;
    const isWorkspaceDependency = semver.satisfies(workspaceVersion, packageVersion) || packageVersion === '*';

    // Rules:
    // - All workspace dependencies that match version are bundled
    // - All blocked versions are bundled
    // - All not allowed versions are bundled
    const isExternal = isAllowed && !isBlocked && !isWorkspaceDependency;
    logger.debug(`Dependency ${name} isBlocked:${isBlocked.toString()}, isAllowed: ${isAllowed.toString()}, isWorkspaceDependency: ${isWorkspaceDependency.toString()}. Will be rewritten -> ${isExternal.toString()}`);
    if (isExternal) {
      acc.external[name] = version;
    } else {
      acc.bundled[name] = version;
    }
    return acc;
  }, {
    external: {},
    bundled: {}
  });
}
//# sourceMappingURL=filterDependencies.js.map