"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.getDependencyInfo = getDependencyInfo;
var _filterDependencies = require("./filterDependencies");
var _getPackageDependencies = require("./getPackageDependencies");
var _importInfo = require("./importInfo");
var _getWorkspaceInfo = _interopRequireDefault(require("./getWorkspaceInfo"));
var _getLocation = _interopRequireDefault(require("./getLocation"));
function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }
async function getDependencyInfo(target) {
  const {
    manifest: packageDependencies,
    resolutions: packageResolutions,
    selectiveCDNResolutions,
    rawImports
  } = await (0, _getPackageDependencies.getPackageDependencies)(target);

  // Get workspace info to automatically bundle workspace dependencies
  const workspaceInfo = await (0, _getWorkspaceInfo.default)();
  const workspacePath = await (0, _getLocation.default)(target);

  // Split dependencies between external and bundled
  const {
    external: externalDependencies,
    bundled: bundledDependencies
  } = (0, _filterDependencies.filterDependencies)(workspacePath, {
    dependencies: packageDependencies,
    workspaceInfo
  });
  const {
    external: externalResolutions,
    bundled: bundledResolutions
  } = (0, _filterDependencies.filterDependencies)(workspacePath, {
    dependencies: packageResolutions,
    workspaceInfo
  });
  const importInfo = (0, _importInfo.buildImportInfo)(workspacePath, {
    externalDependencies,
    externalResolutions,
    selectiveCDNResolutions
  });

  // Generate a list of CSS urls to embed in the synthetic index and output package.json.
  const cssImportList = [...rawImports].filter(moduleSpecifier => moduleSpecifier.endsWith('.css')).map(cssModuleSpecifier => (0, _importInfo.rewriteModuleSpecifier)(importInfo, cssModuleSpecifier)).filter(Boolean);
  return {
    importInfo,
    styleImports: new Set(cssImportList),
    bundledDependencies,
    bundledResolutions,
    externalDependencies,
    externalResolutions,
    selectiveCDNResolutions,
    packageDependencies
  };
}
//# sourceMappingURL=getDependencyInfo.js.map