"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.addFiles = addFiles;
exports.cleanGit = cleanGit;
exports.getDiffedFiles = getDiffedFiles;
exports.getStagedFiles = getStagedFiles;
exports.stashChanges = stashChanges;
var _stripAnsi = _interopRequireDefault(require("strip-ansi"));
var _execa = _interopRequireDefault(require("execa"));
var _getModularRoot = _interopRequireDefault(require("./getModularRoot"));
var logger = _interopRequireWildcard(require("./logger"));
function _getRequireWildcardCache(nodeInterop) { if (typeof WeakMap !== "function") return null; var cacheBabelInterop = new WeakMap(); var cacheNodeInterop = new WeakMap(); return (_getRequireWildcardCache = function (nodeInterop) { return nodeInterop ? cacheNodeInterop : cacheBabelInterop; })(nodeInterop); }
function _interopRequireWildcard(obj, nodeInterop) { if (!nodeInterop && obj && obj.__esModule) { return obj; } if (obj === null || typeof obj !== "object" && typeof obj !== "function") { return { default: obj }; } var cache = _getRequireWildcardCache(nodeInterop); if (cache && cache.has(obj)) { return cache.get(obj); } var newObj = {}; var hasPropertyDescriptor = Object.defineProperty && Object.getOwnPropertyDescriptor; for (var key in obj) { if (key !== "default" && Object.prototype.hasOwnProperty.call(obj, key)) { var desc = hasPropertyDescriptor ? Object.getOwnPropertyDescriptor(obj, key) : null; if (desc && (desc.get || desc.set)) { Object.defineProperty(newObj, key, desc); } else { newObj[key] = obj[key]; } } } newObj.default = obj; if (cache) { cache.set(obj, newObj); } return newObj; }
function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }
function cleanGit(cwd) {
  const trackedChanged = (0, _stripAnsi.default)(_execa.default.sync('git', ['status', '-s'], {
    all: true,
    reject: false,
    cwd,
    cleanup: true
  }).stdout);
  return trackedChanged.length === 0;
}
function stashChanges() {
  _execa.default.sync('git', ['stash', '-u']);
  throw new Error('Failed to perform action cleanly. Stashing git changes...');
}
function getGitLocalDefaultBranch() {
  try {
    // this config may be set to a different default branch (e.g. main)
    const result = _execa.default.sync('git', ['config', 'init.defaultBranch']);
    return (0, _stripAnsi.default)(result.stdout);
  } catch (_err) {
    // if there init.defaultBranch hasn't been set, the default is master
    return 'master';
  }
}
function getGitDefaultBranch() {
  try {
    const result = _execa.default.sync('git', ['symbolic-ref', 'refs/remotes/origin/HEAD']);
    const defaultBranch = `origin/${(0, _stripAnsi.default)(result.stdout).split('/').pop()}`;
    logger.debug(`Git default branch calculated from remote origin: ${defaultBranch}`);
    return defaultBranch;
  } catch (err) {
    // no remote origin, look into git config for init.defaultBranch setting
    const defaultBranch = getGitLocalDefaultBranch();
    logger.debug(`Git default branch calculated from local git config: ${defaultBranch}`);
    return defaultBranch;
  }
}
function getModifiedAndUntrackedFileChanges() {
  // get all modified and untracked files, excluding the standard Git exclusion sources
  const lsFiles = _execa.default.sync('git', ['ls-files', '-mo', '--exclude-standard'], {
    cwd: (0, _getModularRoot.default)()
  });
  if (lsFiles.stdout.length) {
    return (0, _stripAnsi.default)(lsFiles.stdout).split('\n');
  }
  return [];
}

// Get all diffed files in standardised order exluding unknown and removed files
function runGitDiff(gitDiffCommand) {
  /**
   * diff-filter=ACMRTUB
   * (A) Added
   * (C) Copied
   * (M) Modified
   * (R) Renamed
   * (T) Type (i.e. regular file, symlink, submodule, …​) changed
   * (U) Unmerged
   * (B) Broken pairing (file that has had at least a certain percentage of its content deleted or changed)
   */
  const diff = _execa.default.sync('git', ['diff', '--name-only', '--diff-filter=ACMRTUB', gitDiffCommand], {
    cwd: (0, _getModularRoot.default)()
  });
  if (diff.stdout.length) {
    return (0, _stripAnsi.default)(diff.stdout).split('\n');
  }
  return [];
}

// Get all diffed files from git remote origin HEAD
function getGitDiff(targetBranch) {
  // get a commit sha between the HEAD of the current branch and git remote origin HEAD
  const sha = _execa.default.sync('git', ['merge-base', 'HEAD', targetBranch], {
    cwd: (0, _getModularRoot.default)()
  });
  return runGitDiff(sha.stdout);
}
function getDiffedFiles(targetBranch = getGitDefaultBranch()) {
  return Array.from(new Set([...getGitDiff(targetBranch), ...getModifiedAndUntrackedFileChanges()]).values());
}

// Get all staged files
function getStagedFiles() {
  // --cached is used instead of --staged for backwards
  // compatibility with older versions of git
  return runGitDiff('--cached');
}

// Stages files in git
function addFiles(files) {
  _execa.default.sync('git', ['add', ...files], {
    cwd: (0, _getModularRoot.default)()
  });
  return;
}
//# sourceMappingURL=gitActions.js.map