"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.buildImportInfo = buildImportInfo;
exports.rewriteModuleSpecifier = rewriteModuleSpecifier;
var _parsePackageName = require("./parsePackageName");
var _config = require("./config");
function buildImportInfo(workspacePath, {
  externalDependencies,
  externalResolutions,
  selectiveCDNResolutions
}) {
  const externalCdnTemplate = (0, _config.getConfig)('externalCdnTemplate', workspacePath);

  // Add react-dom if only react is specified in the dependencies
  if (!externalDependencies['react-dom']) {
    externalDependencies['react-dom'] = externalDependencies['react'];
  }
  if (!externalResolutions['react-dom']) {
    externalResolutions['react-dom'] = externalResolutions['react'];
  }
  const importSet = new Set(Object.keys(externalDependencies));
  return {
    importSet,
    externalResolutions,
    selectiveCDNResolutions,
    externalDependencies,
    externalCdnTemplate
  };
}
function rewriteModuleSpecifier(importInfo, moduleSpecifier) {
  const {
    externalCdnTemplate,
    externalResolutions,
    externalDependencies,
    selectiveCDNResolutions
  } = importInfo;
  const {
    dependencyName: name,
    submodule
  } = (0, _parsePackageName.parsePackageName)(moduleSpecifier);
  const submodulePath = submodule ? `/${submodule}` : '';
  const hasPath = externalCdnTemplate.includes('[path]');
  if (name && externalDependencies[name]) {
    const dependencyUrl = externalCdnTemplate.replace('[name]', name).replace('[version]', externalDependencies[name] ?? externalResolutions[name]).replace('[resolution]', externalResolutions[name]).replace('[path]', submodulePath).replace('[selectiveCDNResolutions]', selectiveCDNResolutions ? Object.entries(selectiveCDNResolutions).map(([key, value]) => `${key}@${value}`).join(',') : '');
    return `${dependencyUrl}${hasPath ? '' : submodulePath}`;
  }
}
//# sourceMappingURL=importInfo.js.map