"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.isInWorkspaces = isInWorkspaces;
var _path = _interopRequireDefault(require("path"));
var _fsExtra = _interopRequireDefault(require("fs-extra"));
var _minimatch = _interopRequireDefault(require("minimatch"));
var _getModularRoot = _interopRequireDefault(require("./getModularRoot"));
function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }
// This checks if a path is included in the workspaces paths of a monorepo
async function isInWorkspaces(targetPath) {
  const workspaceGlobs = await getWorkspaceGlobs();
  return workspaceGlobs.some(glob => (0, _minimatch.default)(targetPath, glob));
}

// This function gets all the globs in "workspaces" field in the root package manifest
async function getWorkspaceGlobs() {
  var _rootPackageJson$work;
  const modularRoot = (0, _getModularRoot.default)();
  const rootPackageJsonPath = _path.default.join(modularRoot, 'package.json');
  const rootPackageJson = await _fsExtra.default.readJSON(rootPackageJsonPath);
  const workspaceGlobs = Array.isArray(rootPackageJson === null || rootPackageJson === void 0 ? void 0 : rootPackageJson.workspaces) ? rootPackageJson === null || rootPackageJson === void 0 ? void 0 : rootPackageJson.workspaces : rootPackageJson === null || rootPackageJson === void 0 ? void 0 : (_rootPackageJson$work = rootPackageJson.workspaces) === null || _rootPackageJson$work === void 0 ? void 0 : _rootPackageJson$work.packages;
  if (!workspaceGlobs) {
    throw new Error(`Root package.json at path "${rootPackageJsonPath}" has no "workspaces" field`);
  }
  return workspaceGlobs;
}
//# sourceMappingURL=isInWorkspaces.js.map