"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.clear = clear;
exports.debug = debug;
exports.error = error;
exports.log = log;
exports.warn = warn;
var _isCi = _interopRequireDefault(require("is-ci"));
var _chalk = _interopRequireDefault(require("chalk"));
function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }
const PREFIX = '[modular] ';
const DEBUG = process.env.MODULAR_LOGGER_DEBUG || process.argv.includes('--verbose');
const SILENT = process.env.MODULAR_LOGGER_MUTE;
const isInteractive = process.stdout.isTTY;
function printStdErr(x) {
  if (SILENT) {
    return;
  }
  x.split('\n').forEach(l => {
    process.stderr.write(_chalk.default.dim(PREFIX) + l + '\n');
  });
}
function printStdOut(x, prefix = '') {
  if (SILENT) {
    return;
  }
  x.split('\n').forEach(l => {
    process.stdout.write(_chalk.default.dim(PREFIX) + prefix + l + '\n');
  });
}
function log(...x) {
  printStdOut(x.join(' '));
}
function warn(...x) {
  printStdErr(_chalk.default.yellow(x.join(' ')));
}
function error(...x) {
  printStdErr(_chalk.default.red(x.join(' ')));
}
function debug(...x) {
  if (DEBUG) {
    printStdOut(x.join(' '), _chalk.default.blue('[debug] '));
  }
}
function clear() {
  // if we're in CI then we'll always want to keep logs for whatever we're doing.
  if (!_isCi.default && isInteractive && !DEBUG) {
    process.stdout.write(process.platform === 'win32' ? '\x1B[2J\x1B[0f' : '\x1B[2J\x1B[3J\x1B[H');
  }
}
//# sourceMappingURL=logger.js.map