"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.ModularTypes = void 0;
exports.getModularType = getModularType;
exports.isBuildableModularType = isBuildableModularType;
exports.isModularType = isModularType;
exports.isStartableModularType = isStartableModularType;
exports.isValidModularType = isValidModularType;
var _path = _interopRequireDefault(require("path"));
var _fsExtra = _interopRequireDefault(require("fs-extra"));
function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }
const packageTypeDefinitions = {
  app: {
    buildable: true,
    testable: true,
    startable: true
  },
  'esm-view': {
    buildable: true,
    testable: true,
    startable: true
  },
  view: {
    buildable: true,
    testable: true,
    startable: true
  },
  package: {
    buildable: true,
    testable: true,
    startable: false
  },
  template: {
    buildable: false,
    testable: false,
    startable: false
  },
  source: {
    buildable: false,
    testable: true,
    startable: false
  }
};
const ModularTypes = Object.keys(packageTypeDefinitions).concat(['root', 'unknown']);
exports.ModularTypes = ModularTypes;
function getModularType(dir) {
  const packageJsonPath = _path.default.join(dir, 'package.json');
  if (_fsExtra.default.existsSync(packageJsonPath)) {
    var _packageJson$modular;
    const packageJson = _fsExtra.default.readJsonSync(packageJsonPath);
    return (_packageJson$modular = packageJson.modular) === null || _packageJson$modular === void 0 ? void 0 : _packageJson$modular.type;
  }
}
function isModularType(dir, type) {
  const packageJsonPath = _path.default.join(dir, 'package.json');
  if (_fsExtra.default.existsSync(packageJsonPath)) {
    var _packageJson$modular2;
    const packageJson = _fsExtra.default.readJsonSync(packageJsonPath);
    return ((_packageJson$modular2 = packageJson.modular) === null || _packageJson$modular2 === void 0 ? void 0 : _packageJson$modular2.type) === type;
  }
  return false;
}
function isValidModularType(type) {
  return ModularTypes.includes(type);
}
function isBuildableModularType(type) {
  var _packageTypeDefinitio;
  return Boolean((_packageTypeDefinitio = packageTypeDefinitions[type]) === null || _packageTypeDefinitio === void 0 ? void 0 : _packageTypeDefinitio.buildable);
}
function isStartableModularType(type) {
  var _packageTypeDefinitio2;
  return Boolean((_packageTypeDefinitio2 = packageTypeDefinitions[type]) === null || _packageTypeDefinitio2 === void 0 ? void 0 : _packageTypeDefinitio2.startable);
}
//# sourceMappingURL=packageTypes.js.map