"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = setupEnv;
exports.setupEnvForDirectory = setupEnvForDirectory;
var path = _interopRequireWildcard(require("path"));
var fs = _interopRequireWildcard(require("fs-extra"));
var _dotenv = require("dotenv");
var _dotenvExpand = require("dotenv-expand");
var _getModularRoot = require("./getModularRoot");
function _getRequireWildcardCache(nodeInterop) { if (typeof WeakMap !== "function") return null; var cacheBabelInterop = new WeakMap(); var cacheNodeInterop = new WeakMap(); return (_getRequireWildcardCache = function (nodeInterop) { return nodeInterop ? cacheNodeInterop : cacheBabelInterop; })(nodeInterop); }
function _interopRequireWildcard(obj, nodeInterop) { if (!nodeInterop && obj && obj.__esModule) { return obj; } if (obj === null || typeof obj !== "object" && typeof obj !== "function") { return { default: obj }; } var cache = _getRequireWildcardCache(nodeInterop); if (cache && cache.has(obj)) { return cache.get(obj); } var newObj = {}; var hasPropertyDescriptor = Object.defineProperty && Object.getOwnPropertyDescriptor; for (var key in obj) { if (key !== "default" && Object.prototype.hasOwnProperty.call(obj, key)) { var desc = hasPropertyDescriptor ? Object.getOwnPropertyDescriptor(obj, key) : null; if (desc && (desc.get || desc.set)) { Object.defineProperty(newObj, key, desc); } else { newObj[key] = obj[key]; } } } newObj.default = obj; if (cache) { cache.set(obj, newObj); } return newObj; }
async function setupEnvForDirectory(dirName) {
  const resolveRelative = relativePath => path.resolve(dirName, relativePath);
  const dotenv = resolveRelative('.env');

  // https://github.com/bkeepers/dotenv#what-other-env-files-can-i-use
  const dotenvFiles = [`${dotenv}.${process.env.NODE_ENV}.local`,
  // Don't include `.env.local` for `test` environment
  // since normally you expect tests to produce the same
  // results for everyone
  // @ts-ignore
  process.env.NODE_ENV !== 'test' && `${dotenv}.local` || '', `${dotenv}.${process.env.NODE_ENV}`, dotenv].filter(Boolean);

  // Load environment variables from .env* files. Suppress warnings using silent
  // if this file is missing. dotenv will never modify any environment variables
  // that have already been set.  Variable expansion is supported in .env files.
  // https://github.com/motdotla/dotenv
  // https://github.com/motdotla/dotenv-expand
  await Promise.all(dotenvFiles.map(async dotenvFile => {
    if (await fs.pathExists(dotenvFile)) {
      (0, _dotenvExpand.expand)((0, _dotenv.config)({
        path: dotenvFile
      }));
    }
  }));
}
async function setupEnv(env) {
  const modularRoot = (0, _getModularRoot.findModularRoot)();

  // setup verbose Logging
  // @ts-ignore
  if (process.env.MODULAR_LOGGER_DEBUG || process.argv.includes('--verbose')) {
    // @ts-ignore
    process.env.MODULAR_LOGGER_DEBUG = 'true';
  }
  if (!modularRoot) {
    return;
  }

  // We support resolving modules according to `NODE_PATH`.
  // This lets you use absolute paths in imports inside large monorepos:
  // https://github.com/facebook/create-react-app/issues/253.
  // It works similar to `NODE_PATH` in Node itself:
  // https://nodejs.org/api/modules.html#modules_loading_from_the_global_folders
  // Note that unlike in Node, only *relative* paths from `NODE_PATH` are honored.
  // Otherwise, we risk importing Node.js core modules into an app instead of webpack shims.
  // https://github.com/facebook/create-react-app/issues/1023#issuecomment-265344421
  // We also resolve them to make sure all tools using them work consistently.
  process.env.NODE_PATH = (process.env.NODE_PATH || '').split(path.delimiter).filter(folder => folder && !path.isAbsolute(folder)).map(folder => path.resolve(modularRoot, folder)).join(path.delimiter);

  // @ts-ignore
  process.env.NODE_ENV = env;
  process.env.BABEL_ENV = env;

  // in the case that NODE_ENV is test then we actually will assume for browserslist
  // that we're running production builds
  // @ts-ignore
  process.env.BROWSERSLIST_ENV = process.env.BROWSERSLIST_ENV || (process.env.NODE_ENV === 'test' ? 'production' : process.env.NODE_ENV);
  await setupEnvForDirectory(modularRoot);
}
//# sourceMappingURL=setupEnv.js.map