"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.computeRegexesFromPackageNames = computeRegexesFromPackageNames;
exports.partitionPackages = partitionPackages;
var _getAllWorkspaces = require("./getAllWorkspaces");
var _getModularRoot = _interopRequireDefault(require("./getModularRoot"));
function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }
// Utilities for handling non-modular packages

/**
 * From a list of package names, discard packages that don't have the required script
 * and partition the remaining packages into two lists of, respectively, Modular and non-Modular workspaces.
 * @param targets list of package names that we want to partition
 * @param workspaceMap the workspace map as returned from getAllWorkspaces
 * @param script the required scripts for non-modular packages
 */
function partitionPackages(targets, workspaceMap, script) {
  // Split testable packages into modular and non-modular
  return targets.reduce(([testableModularTargetList, nonModularTargetList], current) => {
    var _currentPackageInfo$r;
    const currentPackageInfo = workspaceMap.get(current);
    if (currentPackageInfo !== null && currentPackageInfo !== void 0 && currentPackageInfo.modular && currentPackageInfo.modular.type !== 'root') {
      testableModularTargetList.push(currentPackageInfo.name);
    } else if (!(currentPackageInfo !== null && currentPackageInfo !== void 0 && currentPackageInfo.modular) && currentPackageInfo !== null && currentPackageInfo !== void 0 && (_currentPackageInfo$r = currentPackageInfo.rawPackageJson.scripts) !== null && _currentPackageInfo$r !== void 0 && _currentPackageInfo$r[script]) {
      nonModularTargetList.push(currentPackageInfo.name);
    }
    return [testableModularTargetList, nonModularTargetList];
  }, [[], []]);
}
async function computeRegexesFromPackageNames(targets) {
  const allWorkspaces = await (0, _getAllWorkspaces.getAllWorkspaces)((0, _getModularRoot.default)());
  return targets.filter(packageName => {
    var _allWorkspaces$0$get;
    return (_allWorkspaces$0$get = allWorkspaces[0].get(packageName)) === null || _allWorkspaces$0$get === void 0 ? void 0 : _allWorkspaces$0$get.type;
  }).map(packageName => {
    var _allWorkspaces$0$get2;
    return (_allWorkspaces$0$get2 = allWorkspaces[0].get(packageName)) === null || _allWorkspaces$0$get2 === void 0 ? void 0 : _allWorkspaces$0$get2.location;
  }).filter(Boolean);
}
//# sourceMappingURL=unobtrusiveModular.js.map